Module: Google::Apis::FirebaseapphostingV1

Defined in:
lib/google/apis/firebaseapphosting_v1.rb,
lib/google/apis/firebaseapphosting_v1/classes.rb,
lib/google/apis/firebaseapphosting_v1/service.rb,
lib/google/apis/firebaseapphosting_v1/gem_version.rb,
lib/google/apis/firebaseapphosting_v1/representations.rb

Overview

Firebase App Hosting API

Firebase App Hosting streamlines the development and deployment of dynamic Next.js and Angular applications, offering built-in framework support, GitHub integration, and integration with other Firebase products. You can use this API to intervene in the Firebase App Hosting build process and add custom functionality not supported in our default Console & CLI flows, including triggering builds from external CI/CD workflows or deploying from pre-built container images.

Defined Under Namespace

Classes: ArchiveSource, Backend, Build, BuildSource, CancelOperationRequest, Codebase, CodebaseSource, Config, ContainerSource, CustomDomainOperationMetadata, CustomDomainStatus, DnsRecord, DnsRecordSet, DnsUpdates, Domain, DomainOperationMetadata, Empty, EnvironmentVariable, Error, FirebaseAppHostingService, ListBackendsResponse, ListBuildsResponse, ListDomainsResponse, ListLocationsResponse, ListOperationsResponse, ListRolloutsResponse, LiveMigrationStep, Location, ManagedResource, Operation, OperationMetadata, Path, Redirect, Rollout, RolloutPolicy, RunConfig, RunService, ServingBehavior, SourceUserMetadata, Status, Traffic, TrafficSet, TrafficSplit, UserMetadata

Constant Summary collapse

GEM_VERSION =

Version of the google-apis-firebaseapphosting_v1 gem

"0.13.0"
GENERATOR_VERSION =

Version of the code generator used to generate this client

"0.18.0"
REVISION =

Revision of the discovery document this client was generated from

"20260319"
VERSION =

Version of the Firebase App Hosting API this client connects to. This is NOT the gem version.

'V1'
AUTH_CLOUD_PLATFORM =

See, edit, configure, and delete your Google Cloud data and see the email address for your Google Account.

'https://www.googleapis.com/auth/cloud-platform'