Class: Google::Apis::FirebaseapphostingV1::Backend

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/firebaseapphosting_v1/classes.rb,
lib/google/apis/firebaseapphosting_v1/representations.rb,
lib/google/apis/firebaseapphosting_v1/representations.rb

Overview

A backend is the primary resource of App Hosting.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Backend

Returns a new instance of Backend.



191
192
193
# File 'lib/google/apis/firebaseapphosting_v1/classes.rb', line 191

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#annotationsHash<String,String>

Optional. Unstructured key value map that may be set by external tools to store and arbitrary metadata. They are not queryable and should be preserved when modifying objects. Corresponds to the JSON property annotations

Returns:

  • (Hash<String,String>)


83
84
85
# File 'lib/google/apis/firebaseapphosting_v1/classes.rb', line 83

def annotations
  @annotations
end

#app_idString

Optional. The ID of a Web App associated with the backend. Corresponds to the JSON property appId

Returns:

  • (String)


90
91
92
# File 'lib/google/apis/firebaseapphosting_v1/classes.rb', line 90

def app_id
  @app_id
end

#codebaseGoogle::Apis::FirebaseapphostingV1::Codebase

The connection to an external source repository to watch for event-driven updates to the backend. Corresponds to the JSON property codebase



96
97
98
# File 'lib/google/apis/firebaseapphosting_v1/classes.rb', line 96

def codebase
  @codebase
end

#create_timeString

Output only. Time at which the backend was created. Corresponds to the JSON property createTime

Returns:

  • (String)


101
102
103
# File 'lib/google/apis/firebaseapphosting_v1/classes.rb', line 101

def create_time
  @create_time
end

#delete_timeString

Output only. Time at which the backend was deleted. Corresponds to the JSON property deleteTime

Returns:

  • (String)


106
107
108
# File 'lib/google/apis/firebaseapphosting_v1/classes.rb', line 106

def delete_time
  @delete_time
end

#display_nameString

Optional. Human-readable name. 63 character limit. Corresponds to the JSON property displayName

Returns:

  • (String)


111
112
113
# File 'lib/google/apis/firebaseapphosting_v1/classes.rb', line 111

def display_name
  @display_name
end

#environmentString

Optional. The environment name of the backend, used to load environment variables from environment specific configuration. Corresponds to the JSON property environment

Returns:

  • (String)


117
118
119
# File 'lib/google/apis/firebaseapphosting_v1/classes.rb', line 117

def environment
  @environment
end

#etagString

Output only. Server-computed checksum based on other values; may be sent on update or delete to ensure operation is done on expected resource. Corresponds to the JSON property etag

Returns:

  • (String)


123
124
125
# File 'lib/google/apis/firebaseapphosting_v1/classes.rb', line 123

def etag
  @etag
end

#labelsHash<String,String>

Optional. Unstructured key value map that can be used to organize and categorize objects. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


129
130
131
# File 'lib/google/apis/firebaseapphosting_v1/classes.rb', line 129

def labels
  @labels
end

#managed_resourcesArray<Google::Apis::FirebaseapphostingV1::ManagedResource>

Output only. A list of the resources managed by this backend. Corresponds to the JSON property managedResources



134
135
136
# File 'lib/google/apis/firebaseapphosting_v1/classes.rb', line 134

def managed_resources
  @managed_resources
end

#modeString

Optional. Deprecated: Use environment instead. Corresponds to the JSON property mode

Returns:

  • (String)


139
140
141
# File 'lib/google/apis/firebaseapphosting_v1/classes.rb', line 139

def mode
  @mode
end

#nameString

Identifier. The resource name of the backend. Format: projects/project/ locations/locationId/backends/backendId`. Corresponds to the JSON propertyname`

Returns:

  • (String)


145
146
147
# File 'lib/google/apis/firebaseapphosting_v1/classes.rb', line 145

def name
  @name
end

#reconcilingBoolean Also known as: reconciling?

Output only. A field that, if true, indicates that the system is working to make adjustments to the backend during a LRO. Corresponds to the JSON property reconciling

Returns:

  • (Boolean)


151
152
153
# File 'lib/google/apis/firebaseapphosting_v1/classes.rb', line 151

def reconciling
  @reconciling
end

#request_logs_disabledBoolean Also known as: request_logs_disabled?

Optional. A field that, if true, indicates that incoming request logs are disabled for this backend. Incoming request logs are enabled by default. Corresponds to the JSON property requestLogsDisabled

Returns:

  • (Boolean)


158
159
160
# File 'lib/google/apis/firebaseapphosting_v1/classes.rb', line 158

def request_logs_disabled
  @request_logs_disabled
end

#service_accountString

Required. The name of the service account used for Cloud Build and Cloud Run. Should have the role roles/firebaseapphosting.computeRunner or equivalent permissions. Corresponds to the JSON property serviceAccount

Returns:

  • (String)


166
167
168
# File 'lib/google/apis/firebaseapphosting_v1/classes.rb', line 166

def 
  @service_account
end

#serving_localityString

Required. Immutable. Specifies how App Hosting will serve the content for this backend. It will either be contained to a single region (REGIONAL_STRICT) or allowed to use App Hosting's global-replicated serving infrastructure ( GLOBAL_ACCESS). Corresponds to the JSON property servingLocality

Returns:

  • (String)


174
175
176
# File 'lib/google/apis/firebaseapphosting_v1/classes.rb', line 174

def serving_locality
  @serving_locality
end

#uidString

Output only. System-assigned, unique identifier. Corresponds to the JSON property uid

Returns:

  • (String)


179
180
181
# File 'lib/google/apis/firebaseapphosting_v1/classes.rb', line 179

def uid
  @uid
end

#update_timeString

Output only. Time at which the backend was last updated. Corresponds to the JSON property updateTime

Returns:

  • (String)


184
185
186
# File 'lib/google/apis/firebaseapphosting_v1/classes.rb', line 184

def update_time
  @update_time
end

#uriString

Output only. The primary URI to communicate with the backend. Corresponds to the JSON property uri

Returns:

  • (String)


189
190
191
# File 'lib/google/apis/firebaseapphosting_v1/classes.rb', line 189

def uri
  @uri
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
# File 'lib/google/apis/firebaseapphosting_v1/classes.rb', line 196

def update!(**args)
  @annotations = args[:annotations] if args.key?(:annotations)
  @app_id = args[:app_id] if args.key?(:app_id)
  @codebase = args[:codebase] if args.key?(:codebase)
  @create_time = args[:create_time] if args.key?(:create_time)
  @delete_time = args[:delete_time] if args.key?(:delete_time)
  @display_name = args[:display_name] if args.key?(:display_name)
  @environment = args[:environment] if args.key?(:environment)
  @etag = args[:etag] if args.key?(:etag)
  @labels = args[:labels] if args.key?(:labels)
  @managed_resources = args[:managed_resources] if args.key?(:managed_resources)
  @mode = args[:mode] if args.key?(:mode)
  @name = args[:name] if args.key?(:name)
  @reconciling = args[:reconciling] if args.key?(:reconciling)
  @request_logs_disabled = args[:request_logs_disabled] if args.key?(:request_logs_disabled)
  @service_account = args[:service_account] if args.key?(:service_account)
  @serving_locality = args[:serving_locality] if args.key?(:serving_locality)
  @uid = args[:uid] if args.key?(:uid)
  @update_time = args[:update_time] if args.key?(:update_time)
  @uri = args[:uri] if args.key?(:uri)
end