Class: Google::Apis::FirebaseapphostingV1::Config

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/firebaseapphosting_v1/classes.rb,
lib/google/apis/firebaseapphosting_v1/representations.rb,
lib/google/apis/firebaseapphosting_v1/representations.rb

Overview

Additional configuration of the backend for this build.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Config

Returns a new instance of Config.



535
536
537
# File 'lib/google/apis/firebaseapphosting_v1/classes.rb', line 535

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#effective_envArray<Google::Apis::FirebaseapphostingV1::EnvironmentVariable>

Output only. [OUTPUT_ONLY] This field represents all environment variables employed during both the build and runtime. This list reflects the result of merging variables from all sources (Backend.override_env, Build.Config.env, YAML, defaults, system). Each variable includes its origin Corresponds to the JSON property effectiveEnv



518
519
520
# File 'lib/google/apis/firebaseapphosting_v1/classes.rb', line 518

def effective_env
  @effective_env
end

#envArray<Google::Apis::FirebaseapphostingV1::EnvironmentVariable>

Optional. Supplied environment variables for a specific build. Provided at Build creation time and immutable afterwards. This field is only applicable for Builds using a build image - (e.g., ContainerSource or ArchiveSource with locally_built_source) Attempts to set this for other build types will result in an error Corresponds to the JSON property env



527
528
529
# File 'lib/google/apis/firebaseapphosting_v1/classes.rb', line 527

def env
  @env
end

#run_configGoogle::Apis::FirebaseapphostingV1::RunConfig

Configuration applied to the Cloud Run service. Corresponds to the JSON property runConfig



533
534
535
# File 'lib/google/apis/firebaseapphosting_v1/classes.rb', line 533

def run_config
  @run_config
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



540
541
542
543
544
# File 'lib/google/apis/firebaseapphosting_v1/classes.rb', line 540

def update!(**args)
  @effective_env = args[:effective_env] if args.key?(:effective_env)
  @env = args[:env] if args.key?(:env)
  @run_config = args[:run_config] if args.key?(:run_config)
end