Class: Google::Apis::FirebaseapphostingV1::ContainerSource

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/firebaseapphosting_v1/classes.rb,
lib/google/apis/firebaseapphosting_v1/representations.rb,
lib/google/apis/firebaseapphosting_v1/representations.rb

Overview

The URI of an Artifact Registry container image to use as the build source.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ContainerSource

Returns a new instance of ContainerSource.



558
559
560
# File 'lib/google/apis/firebaseapphosting_v1/classes.rb', line 558

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#imageString

Required. A URI representing a container for the backend to use. Corresponds to the JSON property image

Returns:

  • (String)


556
557
558
# File 'lib/google/apis/firebaseapphosting_v1/classes.rb', line 556

def image
  @image
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



563
564
565
# File 'lib/google/apis/firebaseapphosting_v1/classes.rb', line 563

def update!(**args)
  @image = args[:image] if args.key?(:image)
end