Class: Google::Apis::FirebaseapphostingV1::DnsRecord

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/firebaseapphosting_v1/classes.rb,
lib/google/apis/firebaseapphosting_v1/representations.rb,
lib/google/apis/firebaseapphosting_v1/representations.rb

Overview

A representation of a DNS records for a domain. DNS records are resource records that define how systems and services should behave when handling requests for a domain. For example, when you add A records to your domain's DNS records, you're informing other systems (such as your users' web browsers) to contact those IPv4 addresses to retrieve resources relevant to your domain ( such as your App Hosting files).

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ DnsRecord

Returns a new instance of DnsRecord.



715
716
717
# File 'lib/google/apis/firebaseapphosting_v1/classes.rb', line 715

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#domain_nameString

Output only. The domain the record pertains to, e.g. foo.bar.com.. Corresponds to the JSON property domainName

Returns:

  • (String)


685
686
687
# File 'lib/google/apis/firebaseapphosting_v1/classes.rb', line 685

def domain_name
  @domain_name
end

#rdataString

Output only. The data of the record. The meaning of the value depends on record type: - A and AAAA: IP addresses for the domain. - CNAME: Another domain to check for records. - TXT: Arbitrary text strings associated with the domain. App Hosting uses TXT records to determine which Firebase projects have permission to act on the domain's behalf. - CAA: The record's flags, tag, and value, e.g. 0 issue "pki.goog". Corresponds to the JSON property rdata

Returns:

  • (String)


695
696
697
# File 'lib/google/apis/firebaseapphosting_v1/classes.rb', line 695

def rdata
  @rdata
end

#relevant_stateArray<String>

Output only. An enum that indicates which state(s) this DNS record applies to. Populated for all records with an ADD or REMOVE required action. Corresponds to the JSON property relevantState

Returns:

  • (Array<String>)


701
702
703
# File 'lib/google/apis/firebaseapphosting_v1/classes.rb', line 701

def relevant_state
  @relevant_state
end

#required_actionString

Output only. An enum that indicates the a required action for this record. Populated when the record is part of a required change in a DnsUpdates discovered or desired record set. Corresponds to the JSON property requiredAction

Returns:

  • (String)


708
709
710
# File 'lib/google/apis/firebaseapphosting_v1/classes.rb', line 708

def required_action
  @required_action
end

#typeString

Output only. The record's type, which determines what data the record contains. Corresponds to the JSON property type

Returns:

  • (String)


713
714
715
# File 'lib/google/apis/firebaseapphosting_v1/classes.rb', line 713

def type
  @type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



720
721
722
723
724
725
726
# File 'lib/google/apis/firebaseapphosting_v1/classes.rb', line 720

def update!(**args)
  @domain_name = args[:domain_name] if args.key?(:domain_name)
  @rdata = args[:rdata] if args.key?(:rdata)
  @relevant_state = args[:relevant_state] if args.key?(:relevant_state)
  @required_action = args[:required_action] if args.key?(:required_action)
  @type = args[:type] if args.key?(:type)
end