Class: Google::Apis::FirebaseapphostingV1::DnsRecordSet

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/firebaseapphosting_v1/classes.rb,
lib/google/apis/firebaseapphosting_v1/representations.rb,
lib/google/apis/firebaseapphosting_v1/representations.rb

Overview

A set of DNS records relevant to the setup and maintenance of a custom domain in App Hosting.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ DnsRecordSet

Returns a new instance of DnsRecordSet.



754
755
756
# File 'lib/google/apis/firebaseapphosting_v1/classes.rb', line 754

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#check_errorGoogle::Apis::FirebaseapphostingV1::Status

The Status type defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs. It is used by gRPC. Each Status message contains three pieces of data: error code, error message, and error details. You can find out more about this error model and how to work with it in the API Design Guide. Corresponds to the JSON property checkError



742
743
744
# File 'lib/google/apis/firebaseapphosting_v1/classes.rb', line 742

def check_error
  @check_error
end

#domain_nameString

Output only. The domain name the record set pertains to. Corresponds to the JSON property domainName

Returns:

  • (String)


747
748
749
# File 'lib/google/apis/firebaseapphosting_v1/classes.rb', line 747

def domain_name
  @domain_name
end

#recordsArray<Google::Apis::FirebaseapphostingV1::DnsRecord>

Output only. Records on the domain. Corresponds to the JSON property records



752
753
754
# File 'lib/google/apis/firebaseapphosting_v1/classes.rb', line 752

def records
  @records
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



759
760
761
762
763
# File 'lib/google/apis/firebaseapphosting_v1/classes.rb', line 759

def update!(**args)
  @check_error = args[:check_error] if args.key?(:check_error)
  @domain_name = args[:domain_name] if args.key?(:domain_name)
  @records = args[:records] if args.key?(:records)
end