Class: Google::Apis::FirebaseapphostingV1::DnsUpdates

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/firebaseapphosting_v1/classes.rb,
lib/google/apis/firebaseapphosting_v1/representations.rb,
lib/google/apis/firebaseapphosting_v1/representations.rb

Overview

A set of DNS record updates that you should make to allow App Hosting to serve secure content in response to requests against your domain. These updates present the current state of your domain's and related subdomains' DNS records when App Hosting last queried them, and the desired set of records that App Hosting needs to see before your custom domain can be fully active.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ DnsUpdates

Returns a new instance of DnsUpdates.



797
798
799
# File 'lib/google/apis/firebaseapphosting_v1/classes.rb', line 797

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#check_timeString

Output only. The last time App Hosting checked your custom domain's DNS records. Corresponds to the JSON property checkTime

Returns:

  • (String)


778
779
780
# File 'lib/google/apis/firebaseapphosting_v1/classes.rb', line 778

def check_time
  @check_time
end

#desiredArray<Google::Apis::FirebaseapphostingV1::DnsRecordSet>

Output only. The set of DNS records App Hosting needs in order to be able to serve secure content on the domain. Corresponds to the JSON property desired



784
785
786
# File 'lib/google/apis/firebaseapphosting_v1/classes.rb', line 784

def desired
  @desired
end

#discoveredArray<Google::Apis::FirebaseapphostingV1::DnsRecordSet>

Output only. The set of DNS records App Hosting discovered when inspecting a domain. Corresponds to the JSON property discovered



790
791
792
# File 'lib/google/apis/firebaseapphosting_v1/classes.rb', line 790

def discovered
  @discovered
end

#domain_nameString

Output only. The domain name the DNS updates pertain to. Corresponds to the JSON property domainName

Returns:

  • (String)


795
796
797
# File 'lib/google/apis/firebaseapphosting_v1/classes.rb', line 795

def domain_name
  @domain_name
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



802
803
804
805
806
807
# File 'lib/google/apis/firebaseapphosting_v1/classes.rb', line 802

def update!(**args)
  @check_time = args[:check_time] if args.key?(:check_time)
  @desired = args[:desired] if args.key?(:desired)
  @discovered = args[:discovered] if args.key?(:discovered)
  @domain_name = args[:domain_name] if args.key?(:domain_name)
end