Class: Google::Apis::FirebaseapphostingV1::Domain

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/firebaseapphosting_v1/classes.rb,
lib/google/apis/firebaseapphosting_v1/representations.rb,
lib/google/apis/firebaseapphosting_v1/representations.rb

Overview

A domain name that is associated with a backend.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Domain

Returns a new instance of Domain.



890
891
892
# File 'lib/google/apis/firebaseapphosting_v1/classes.rb', line 890

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#annotationsHash<String,String>

Optional. Annotations as key value pairs. Corresponds to the JSON property annotations

Returns:

  • (Hash<String,String>)


817
818
819
# File 'lib/google/apis/firebaseapphosting_v1/classes.rb', line 817

def annotations
  @annotations
end

#create_timeString

Output only. Time at which the domain was created. Corresponds to the JSON property createTime

Returns:

  • (String)


822
823
824
# File 'lib/google/apis/firebaseapphosting_v1/classes.rb', line 822

def create_time
  @create_time
end

#custom_domain_statusGoogle::Apis::FirebaseapphostingV1::CustomDomainStatus

The status of a custom domain's linkage to a backend. Corresponds to the JSON property customDomainStatus



827
828
829
# File 'lib/google/apis/firebaseapphosting_v1/classes.rb', line 827

def custom_domain_status
  @custom_domain_status
end

#delete_timeString

Output only. Time at which the domain was deleted. Corresponds to the JSON property deleteTime

Returns:

  • (String)


832
833
834
# File 'lib/google/apis/firebaseapphosting_v1/classes.rb', line 832

def delete_time
  @delete_time
end

#disabledBoolean Also known as: disabled?

Optional. Whether the domain is disabled. Defaults to false. Corresponds to the JSON property disabled

Returns:

  • (Boolean)


837
838
839
# File 'lib/google/apis/firebaseapphosting_v1/classes.rb', line 837

def disabled
  @disabled
end

#display_nameString

Optional. Mutable human-readable name for the domain. 63 character limit. e.g. prod domain. Corresponds to the JSON property displayName

Returns:

  • (String)


844
845
846
# File 'lib/google/apis/firebaseapphosting_v1/classes.rb', line 844

def display_name
  @display_name
end

#etagString

Output only. Server-computed checksum based on other values; may be sent on update or delete to ensure operation is done on expected resource. Corresponds to the JSON property etag

Returns:

  • (String)


850
851
852
# File 'lib/google/apis/firebaseapphosting_v1/classes.rb', line 850

def etag
  @etag
end

#labelsHash<String,String>

Optional. Labels as key value pairs. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


855
856
857
# File 'lib/google/apis/firebaseapphosting_v1/classes.rb', line 855

def labels
  @labels
end

#nameString

Identifier. The resource name of the domain, e.g. /projects/p/locations/l/ backends/b/domains/foo.com Corresponds to the JSON property name

Returns:

  • (String)


861
862
863
# File 'lib/google/apis/firebaseapphosting_v1/classes.rb', line 861

def name
  @name
end

#reconcilingBoolean Also known as: reconciling?

Output only. A field that, if true, indicates that the build has an ongoing LRO. Corresponds to the JSON property reconciling

Returns:

  • (Boolean)


867
868
869
# File 'lib/google/apis/firebaseapphosting_v1/classes.rb', line 867

def reconciling
  @reconciling
end

#serveGoogle::Apis::FirebaseapphostingV1::ServingBehavior

Indicates whether App Hosting will serve content on the domain. Corresponds to the JSON property serve



873
874
875
# File 'lib/google/apis/firebaseapphosting_v1/classes.rb', line 873

def serve
  @serve
end

#typeString

Output only. The type of the domain. Corresponds to the JSON property type

Returns:

  • (String)


878
879
880
# File 'lib/google/apis/firebaseapphosting_v1/classes.rb', line 878

def type
  @type
end

#uidString

Output only. System-assigned, unique identifier. Corresponds to the JSON property uid

Returns:

  • (String)


883
884
885
# File 'lib/google/apis/firebaseapphosting_v1/classes.rb', line 883

def uid
  @uid
end

#update_timeString

Output only. Time at which the domain was last updated. Corresponds to the JSON property updateTime

Returns:

  • (String)


888
889
890
# File 'lib/google/apis/firebaseapphosting_v1/classes.rb', line 888

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



895
896
897
898
899
900
901
902
903
904
905
906
907
908
909
910
# File 'lib/google/apis/firebaseapphosting_v1/classes.rb', line 895

def update!(**args)
  @annotations = args[:annotations] if args.key?(:annotations)
  @create_time = args[:create_time] if args.key?(:create_time)
  @custom_domain_status = args[:custom_domain_status] if args.key?(:custom_domain_status)
  @delete_time = args[:delete_time] if args.key?(:delete_time)
  @disabled = args[:disabled] if args.key?(:disabled)
  @display_name = args[:display_name] if args.key?(:display_name)
  @etag = args[:etag] if args.key?(:etag)
  @labels = args[:labels] if args.key?(:labels)
  @name = args[:name] if args.key?(:name)
  @reconciling = args[:reconciling] if args.key?(:reconciling)
  @serve = args[:serve] if args.key?(:serve)
  @type = args[:type] if args.key?(:type)
  @uid = args[:uid] if args.key?(:uid)
  @update_time = args[:update_time] if args.key?(:update_time)
end