Class: Google::Apis::FirebaseapphostingV1::DomainOperationMetadata

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/firebaseapphosting_v1/classes.rb,
lib/google/apis/firebaseapphosting_v1/representations.rb,
lib/google/apis/firebaseapphosting_v1/representations.rb

Overview

Represents the metadata of a long-running operation on domains.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ DomainOperationMetadata

Returns a new instance of DomainOperationMetadata.



961
962
963
# File 'lib/google/apis/firebaseapphosting_v1/classes.rb', line 961

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#api_versionString

Output only. API version used to start the operation. Corresponds to the JSON property apiVersion

Returns:

  • (String)


920
921
922
# File 'lib/google/apis/firebaseapphosting_v1/classes.rb', line 920

def api_version
  @api_version
end

#create_timeString

Output only. The time the operation was created. Corresponds to the JSON property createTime

Returns:

  • (String)


925
926
927
# File 'lib/google/apis/firebaseapphosting_v1/classes.rb', line 925

def create_time
  @create_time
end

#custom_domain_operation_metadataGoogle::Apis::FirebaseapphostingV1::CustomDomainOperationMetadata

Additional metadata for operations on custom domains. Corresponds to the JSON property customDomainOperationMetadata



930
931
932
# File 'lib/google/apis/firebaseapphosting_v1/classes.rb', line 930

def 
  @custom_domain_operation_metadata
end

#end_timeString

Output only. The time the operation finished running. Corresponds to the JSON property endTime

Returns:

  • (String)


935
936
937
# File 'lib/google/apis/firebaseapphosting_v1/classes.rb', line 935

def end_time
  @end_time
end

#requested_cancellationBoolean Also known as: requested_cancellation?

Output only. Identifies whether the user has requested cancellation of the operation. Operations that have been cancelled successfully have Operation. error value with a google.rpc.Status.code of 1, corresponding to Code. CANCELLED. Corresponds to the JSON property requestedCancellation

Returns:

  • (Boolean)


943
944
945
# File 'lib/google/apis/firebaseapphosting_v1/classes.rb', line 943

def requested_cancellation
  @requested_cancellation
end

#status_messageString

Output only. Human-readable status of the operation, if any. Corresponds to the JSON property statusMessage

Returns:

  • (String)


949
950
951
# File 'lib/google/apis/firebaseapphosting_v1/classes.rb', line 949

def status_message
  @status_message
end

#targetString

Output only. Server-defined resource path for the target of the operation. Corresponds to the JSON property target

Returns:

  • (String)


954
955
956
# File 'lib/google/apis/firebaseapphosting_v1/classes.rb', line 954

def target
  @target
end

#verbString

Output only. Name of the verb executed by the operation. Corresponds to the JSON property verb

Returns:

  • (String)


959
960
961
# File 'lib/google/apis/firebaseapphosting_v1/classes.rb', line 959

def verb
  @verb
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



966
967
968
969
970
971
972
973
974
975
# File 'lib/google/apis/firebaseapphosting_v1/classes.rb', line 966

def update!(**args)
  @api_version = args[:api_version] if args.key?(:api_version)
  @create_time = args[:create_time] if args.key?(:create_time)
  @custom_domain_operation_metadata = args[:custom_domain_operation_metadata] if args.key?(:custom_domain_operation_metadata)
  @end_time = args[:end_time] if args.key?(:end_time)
  @requested_cancellation = args[:requested_cancellation] if args.key?(:requested_cancellation)
  @status_message = args[:status_message] if args.key?(:status_message)
  @target = args[:target] if args.key?(:target)
  @verb = args[:verb] if args.key?(:verb)
end