Class: Google::Apis::FirebaseapphostingV1::Error

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/firebaseapphosting_v1/classes.rb,
lib/google/apis/firebaseapphosting_v1/representations.rb,
lib/google/apis/firebaseapphosting_v1/representations.rb

Overview

The container for the rpc status and source for any errors found during the build process.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Error

Returns a new instance of Error.



1078
1079
1080
# File 'lib/google/apis/firebaseapphosting_v1/classes.rb', line 1078

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#cloud_resourceString

Output only. Resource link Corresponds to the JSON property cloudResource

Returns:

  • (String)


1061
1062
1063
# File 'lib/google/apis/firebaseapphosting_v1/classes.rb', line 1061

def cloud_resource
  @cloud_resource
end

#errorGoogle::Apis::FirebaseapphostingV1::Status

The Status type defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs. It is used by gRPC. Each Status message contains three pieces of data: error code, error message, and error details. You can find out more about this error model and how to work with it in the API Design Guide. Corresponds to the JSON property error



1071
1072
1073
# File 'lib/google/apis/firebaseapphosting_v1/classes.rb', line 1071

def error
  @error
end

#error_sourceString

Output only. The source of the error for the build, if in a FAILED state. Corresponds to the JSON property errorSource

Returns:

  • (String)


1076
1077
1078
# File 'lib/google/apis/firebaseapphosting_v1/classes.rb', line 1076

def error_source
  @error_source
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1083
1084
1085
1086
1087
# File 'lib/google/apis/firebaseapphosting_v1/classes.rb', line 1083

def update!(**args)
  @cloud_resource = args[:cloud_resource] if args.key?(:cloud_resource)
  @error = args[:error] if args.key?(:error)
  @error_source = args[:error_source] if args.key?(:error_source)
end