Class: Google::Apis::FirebaseapphostingV1::FirebaseAppHostingService
- Inherits:
-
Core::BaseService
- Object
- Core::BaseService
- Google::Apis::FirebaseapphostingV1::FirebaseAppHostingService
- Defined in:
- lib/google/apis/firebaseapphosting_v1/service.rb
Overview
Firebase App Hosting API
Firebase App Hosting streamlines the development and deployment of dynamic Next.js and Angular applications, offering built-in framework support, GitHub integration, and integration with other Firebase products. You can use this API to intervene in the Firebase App Hosting build process and add custom functionality not supported in our default Console & CLI flows, including triggering builds from external CI/CD workflows or deploying from pre-built container images.
Constant Summary collapse
- DEFAULT_ENDPOINT_TEMPLATE =
"https://firebaseapphosting.$UNIVERSE_DOMAIN$/"
Instance Attribute Summary collapse
-
#key ⇒ String
API key.
-
#quota_user ⇒ String
Available to use for quota purposes for server-side applications.
Instance Method Summary collapse
-
#cancel_operation(name, cancel_operation_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::FirebaseapphostingV1::Empty
Starts asynchronous cancellation on a long-running operation.
-
#create_project_location_backend(parent, backend_object = nil, backend_id: nil, request_id: nil, validate_only: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::FirebaseapphostingV1::Operation
Creates a new backend in a given project and location.
-
#create_project_location_backend_build(parent, build_object = nil, build_id: nil, request_id: nil, validate_only: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::FirebaseapphostingV1::Operation
Creates a new build for a backend.
-
#create_project_location_backend_domain(parent, domain_object = nil, domain_id: nil, request_id: nil, validate_only: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::FirebaseapphostingV1::Operation
Links a new domain to a backend.
-
#create_project_location_backend_rollout(parent, rollout_object = nil, request_id: nil, rollout_id: nil, validate_only: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::FirebaseapphostingV1::Operation
Creates a new rollout for a backend.
-
#delete_project_location_backend(name, etag: nil, force: nil, request_id: nil, validate_only: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::FirebaseapphostingV1::Operation
Deletes a single backend.
-
#delete_project_location_backend_build(name, etag: nil, request_id: nil, validate_only: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::FirebaseapphostingV1::Operation
Deletes a single build.
-
#delete_project_location_backend_domain(name, etag: nil, request_id: nil, validate_only: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::FirebaseapphostingV1::Operation
Deletes a single domain.
-
#delete_project_location_operation(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::FirebaseapphostingV1::Empty
Deletes a long-running operation.
-
#get_project_location(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::FirebaseapphostingV1::Location
Gets information about a location.
-
#get_project_location_backend(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::FirebaseapphostingV1::Backend
Gets information about a backend.
-
#get_project_location_backend_build(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::FirebaseapphostingV1::Build
Gets information about a build.
-
#get_project_location_backend_domain(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::FirebaseapphostingV1::Domain
Gets information about a domain.
-
#get_project_location_backend_rollout(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::FirebaseapphostingV1::Rollout
Gets information about a rollout.
-
#get_project_location_backend_traffic(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::FirebaseapphostingV1::Traffic
Gets information about a backend's traffic.
-
#get_project_location_operation(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::FirebaseapphostingV1::Operation
Gets the latest state of a long-running operation.
-
#initialize ⇒ FirebaseAppHostingService
constructor
A new instance of FirebaseAppHostingService.
-
#list_project_location_backend_builds(parent, filter: nil, order_by: nil, page_size: nil, page_token: nil, show_deleted: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::FirebaseapphostingV1::ListBuildsResponse
Lists builds in a given project, location, and backend.
-
#list_project_location_backend_domains(parent, filter: nil, order_by: nil, page_size: nil, page_token: nil, show_deleted: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::FirebaseapphostingV1::ListDomainsResponse
Lists domains of a backend.
-
#list_project_location_backend_rollouts(parent, filter: nil, order_by: nil, page_size: nil, page_token: nil, show_deleted: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::FirebaseapphostingV1::ListRolloutsResponse
Lists rollouts for a backend.
-
#list_project_location_backends(parent, filter: nil, order_by: nil, page_size: nil, page_token: nil, show_deleted: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::FirebaseapphostingV1::ListBackendsResponse
Lists backends in a given project and location.
-
#list_project_location_operations(name, filter: nil, page_size: nil, page_token: nil, return_partial_success: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::FirebaseapphostingV1::ListOperationsResponse
Lists operations that match the specified filter in the request.
-
#list_project_locations(name, extra_location_types: nil, filter: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::FirebaseapphostingV1::ListLocationsResponse
Lists information about the supported locations for this service.
-
#patch_project_location_backend(name, backend_object = nil, allow_missing: nil, request_id: nil, update_mask: nil, validate_only: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::FirebaseapphostingV1::Operation
Updates the information for a single backend.
-
#patch_project_location_backend_domain(name, domain_object = nil, allow_missing: nil, request_id: nil, update_mask: nil, validate_only: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::FirebaseapphostingV1::Operation
Updates the information for a single domain.
-
#patch_project_location_backend_traffic(name, traffic_object = nil, request_id: nil, update_mask: nil, validate_only: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::FirebaseapphostingV1::Operation
Updates a backend's traffic.
Constructor Details
#initialize ⇒ FirebaseAppHostingService
Returns a new instance of FirebaseAppHostingService.
53 54 55 56 57 58 |
# File 'lib/google/apis/firebaseapphosting_v1/service.rb', line 53 def initialize super(DEFAULT_ENDPOINT_TEMPLATE, '', client_name: 'google-apis-firebaseapphosting_v1', client_version: Google::Apis::FirebaseapphostingV1::GEM_VERSION) @batch_path = 'batch' end |
Instance Attribute Details
#key ⇒ String
Returns API key. Your API key identifies your project and provides you with API access, quota, and reports. Required unless you provide an OAuth 2.0 token.
46 47 48 |
# File 'lib/google/apis/firebaseapphosting_v1/service.rb', line 46 def key @key end |
#quota_user ⇒ String
Returns Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.
51 52 53 |
# File 'lib/google/apis/firebaseapphosting_v1/service.rb', line 51 def quota_user @quota_user end |
Instance Method Details
#cancel_operation(name, cancel_operation_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::FirebaseapphostingV1::Empty
Starts asynchronous cancellation on a long-running operation. The server makes
a best effort to cancel the operation, but success is not guaranteed. If the
server doesn't support this method, it returns google.rpc.Code.UNIMPLEMENTED.
Clients can use Operations.GetOperation or other methods to check whether the
cancellation succeeded or whether the operation completed despite cancellation.
On successful cancellation, the operation is not deleted; instead, it becomes
an operation with an Operation.error value with a google.rpc.Status.code of 1
, corresponding to Code.CANCELLED.
1082 1083 1084 1085 1086 1087 1088 1089 1090 1091 1092 |
# File 'lib/google/apis/firebaseapphosting_v1/service.rb', line 1082 def cancel_operation(name, cancel_operation_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1/{+name}:cancel', ) command.request_representation = Google::Apis::FirebaseapphostingV1::CancelOperationRequest::Representation command.request_object = cancel_operation_request_object command.response_representation = Google::Apis::FirebaseapphostingV1::Empty::Representation command.response_class = Google::Apis::FirebaseapphostingV1::Empty command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#create_project_location_backend(parent, backend_object = nil, backend_id: nil, request_id: nil, validate_only: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::FirebaseapphostingV1::Operation
Creates a new backend in a given project and location.
185 186 187 188 189 190 191 192 193 194 195 196 197 198 |
# File 'lib/google/apis/firebaseapphosting_v1/service.rb', line 185 def create_project_location_backend(parent, backend_object = nil, backend_id: nil, request_id: nil, validate_only: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1/{+parent}/backends', ) command.request_representation = Google::Apis::FirebaseapphostingV1::Backend::Representation command.request_object = backend_object command.response_representation = Google::Apis::FirebaseapphostingV1::Operation::Representation command.response_class = Google::Apis::FirebaseapphostingV1::Operation command.params['parent'] = parent unless parent.nil? command.query['backendId'] = backend_id unless backend_id.nil? command.query['requestId'] = request_id unless request_id.nil? command.query['validateOnly'] = validate_only unless validate_only.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#create_project_location_backend_build(parent, build_object = nil, build_id: nil, request_id: nil, validate_only: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::FirebaseapphostingV1::Operation
Creates a new build for a backend.
436 437 438 439 440 441 442 443 444 445 446 447 448 449 |
# File 'lib/google/apis/firebaseapphosting_v1/service.rb', line 436 def create_project_location_backend_build(parent, build_object = nil, build_id: nil, request_id: nil, validate_only: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1/{+parent}/builds', ) command.request_representation = Google::Apis::FirebaseapphostingV1::Build::Representation command.request_object = build_object command.response_representation = Google::Apis::FirebaseapphostingV1::Operation::Representation command.response_class = Google::Apis::FirebaseapphostingV1::Operation command.params['parent'] = parent unless parent.nil? command.query['buildId'] = build_id unless build_id.nil? command.query['requestId'] = request_id unless request_id.nil? command.query['validateOnly'] = validate_only unless validate_only.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#create_project_location_backend_domain(parent, domain_object = nil, domain_id: nil, request_id: nil, validate_only: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::FirebaseapphostingV1::Operation
Links a new domain to a backend.
622 623 624 625 626 627 628 629 630 631 632 633 634 635 |
# File 'lib/google/apis/firebaseapphosting_v1/service.rb', line 622 def create_project_location_backend_domain(parent, domain_object = nil, domain_id: nil, request_id: nil, validate_only: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1/{+parent}/domains', ) command.request_representation = Google::Apis::FirebaseapphostingV1::Domain::Representation command.request_object = domain_object command.response_representation = Google::Apis::FirebaseapphostingV1::Operation::Representation command.response_class = Google::Apis::FirebaseapphostingV1::Operation command.params['parent'] = parent unless parent.nil? command.query['domainId'] = domain_id unless domain_id.nil? command.query['requestId'] = request_id unless request_id.nil? command.query['validateOnly'] = validate_only unless validate_only.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#create_project_location_backend_rollout(parent, rollout_object = nil, request_id: nil, rollout_id: nil, validate_only: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::FirebaseapphostingV1::Operation
Creates a new rollout for a backend.
869 870 871 872 873 874 875 876 877 878 879 880 881 882 |
# File 'lib/google/apis/firebaseapphosting_v1/service.rb', line 869 def create_project_location_backend_rollout(parent, rollout_object = nil, request_id: nil, rollout_id: nil, validate_only: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1/{+parent}/rollouts', ) command.request_representation = Google::Apis::FirebaseapphostingV1::Rollout::Representation command.request_object = rollout_object command.response_representation = Google::Apis::FirebaseapphostingV1::Operation::Representation command.response_class = Google::Apis::FirebaseapphostingV1::Operation command.params['parent'] = parent unless parent.nil? command.query['requestId'] = request_id unless request_id.nil? command.query['rolloutId'] = rollout_id unless rollout_id.nil? command.query['validateOnly'] = validate_only unless validate_only.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#delete_project_location_backend(name, etag: nil, force: nil, request_id: nil, validate_only: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::FirebaseapphostingV1::Operation
Deletes a single backend.
241 242 243 244 245 246 247 248 249 250 251 252 253 |
# File 'lib/google/apis/firebaseapphosting_v1/service.rb', line 241 def delete_project_location_backend(name, etag: nil, force: nil, request_id: nil, validate_only: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:delete, 'v1/{+name}', ) command.response_representation = Google::Apis::FirebaseapphostingV1::Operation::Representation command.response_class = Google::Apis::FirebaseapphostingV1::Operation command.params['name'] = name unless name.nil? command.query['etag'] = etag unless etag.nil? command.query['force'] = force unless force.nil? command.query['requestId'] = request_id unless request_id.nil? command.query['validateOnly'] = validate_only unless validate_only.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#delete_project_location_backend_build(name, etag: nil, request_id: nil, validate_only: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::FirebaseapphostingV1::Operation
Deletes a single build.
489 490 491 492 493 494 495 496 497 498 499 500 |
# File 'lib/google/apis/firebaseapphosting_v1/service.rb', line 489 def delete_project_location_backend_build(name, etag: nil, request_id: nil, validate_only: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:delete, 'v1/{+name}', ) command.response_representation = Google::Apis::FirebaseapphostingV1::Operation::Representation command.response_class = Google::Apis::FirebaseapphostingV1::Operation command.params['name'] = name unless name.nil? command.query['etag'] = etag unless etag.nil? command.query['requestId'] = request_id unless request_id.nil? command.query['validateOnly'] = validate_only unless validate_only.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#delete_project_location_backend_domain(name, etag: nil, request_id: nil, validate_only: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::FirebaseapphostingV1::Operation
Deletes a single domain.
675 676 677 678 679 680 681 682 683 684 685 686 |
# File 'lib/google/apis/firebaseapphosting_v1/service.rb', line 675 def delete_project_location_backend_domain(name, etag: nil, request_id: nil, validate_only: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:delete, 'v1/{+name}', ) command.response_representation = Google::Apis::FirebaseapphostingV1::Operation::Representation command.response_class = Google::Apis::FirebaseapphostingV1::Operation command.params['name'] = name unless name.nil? command.query['etag'] = etag unless etag.nil? command.query['requestId'] = request_id unless request_id.nil? command.query['validateOnly'] = validate_only unless validate_only.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#delete_project_location_operation(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::FirebaseapphostingV1::Empty
Deletes a long-running operation. This method indicates that the client is no
longer interested in the operation result. It does not cancel the operation.
If the server doesn't support this method, it returns google.rpc.Code.
UNIMPLEMENTED.
1117 1118 1119 1120 1121 1122 1123 1124 1125 |
# File 'lib/google/apis/firebaseapphosting_v1/service.rb', line 1117 def delete_project_location_operation(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:delete, 'v1/{+name}', ) command.response_representation = Google::Apis::FirebaseapphostingV1::Empty::Representation command.response_class = Google::Apis::FirebaseapphostingV1::Empty command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_project_location(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::FirebaseapphostingV1::Location
Gets information about a location.
80 81 82 83 84 85 86 87 88 |
# File 'lib/google/apis/firebaseapphosting_v1/service.rb', line 80 def get_project_location(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+name}', ) command.response_representation = Google::Apis::FirebaseapphostingV1::Location::Representation command.response_class = Google::Apis::FirebaseapphostingV1::Location command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_project_location_backend(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::FirebaseapphostingV1::Backend
Gets information about a backend.
276 277 278 279 280 281 282 283 284 |
# File 'lib/google/apis/firebaseapphosting_v1/service.rb', line 276 def get_project_location_backend(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+name}', ) command.response_representation = Google::Apis::FirebaseapphostingV1::Backend::Representation command.response_class = Google::Apis::FirebaseapphostingV1::Backend command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_project_location_backend_build(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::FirebaseapphostingV1::Build
Gets information about a build.
523 524 525 526 527 528 529 530 531 |
# File 'lib/google/apis/firebaseapphosting_v1/service.rb', line 523 def get_project_location_backend_build(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+name}', ) command.response_representation = Google::Apis::FirebaseapphostingV1::Build::Representation command.response_class = Google::Apis::FirebaseapphostingV1::Build command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_project_location_backend_domain(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::FirebaseapphostingV1::Domain
Gets information about a domain.
709 710 711 712 713 714 715 716 717 |
# File 'lib/google/apis/firebaseapphosting_v1/service.rb', line 709 def get_project_location_backend_domain(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+name}', ) command.response_representation = Google::Apis::FirebaseapphostingV1::Domain::Representation command.response_class = Google::Apis::FirebaseapphostingV1::Domain command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_project_location_backend_rollout(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::FirebaseapphostingV1::Rollout
Gets information about a rollout.
905 906 907 908 909 910 911 912 913 |
# File 'lib/google/apis/firebaseapphosting_v1/service.rb', line 905 def get_project_location_backend_rollout(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+name}', ) command.response_representation = Google::Apis::FirebaseapphostingV1::Rollout::Representation command.response_class = Google::Apis::FirebaseapphostingV1::Rollout command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_project_location_backend_traffic(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::FirebaseapphostingV1::Traffic
Gets information about a backend's traffic.
987 988 989 990 991 992 993 994 995 |
# File 'lib/google/apis/firebaseapphosting_v1/service.rb', line 987 def get_project_location_backend_traffic(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+name}', ) command.response_representation = Google::Apis::FirebaseapphostingV1::Traffic::Representation command.response_class = Google::Apis::FirebaseapphostingV1::Traffic command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_project_location_operation(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::FirebaseapphostingV1::Operation
Gets the latest state of a long-running operation. Clients can use this method to poll the operation result at intervals as recommended by the API service.
1148 1149 1150 1151 1152 1153 1154 1155 1156 |
# File 'lib/google/apis/firebaseapphosting_v1/service.rb', line 1148 def get_project_location_operation(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+name}', ) command.response_representation = Google::Apis::FirebaseapphostingV1::Operation::Representation command.response_class = Google::Apis::FirebaseapphostingV1::Operation command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_project_location_backend_builds(parent, filter: nil, order_by: nil, page_size: nil, page_token: nil, show_deleted: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::FirebaseapphostingV1::ListBuildsResponse
Lists builds in a given project, location, and backend.
569 570 571 572 573 574 575 576 577 578 579 580 581 582 |
# File 'lib/google/apis/firebaseapphosting_v1/service.rb', line 569 def list_project_location_backend_builds(parent, filter: nil, order_by: nil, page_size: nil, page_token: nil, show_deleted: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+parent}/builds', ) command.response_representation = Google::Apis::FirebaseapphostingV1::ListBuildsResponse::Representation command.response_class = Google::Apis::FirebaseapphostingV1::ListBuildsResponse command.params['parent'] = parent unless parent.nil? command.query['filter'] = filter unless filter.nil? command.query['orderBy'] = order_by unless order_by.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['showDeleted'] = show_deleted unless show_deleted.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_project_location_backend_domains(parent, filter: nil, order_by: nil, page_size: nil, page_token: nil, show_deleted: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::FirebaseapphostingV1::ListDomainsResponse
Lists domains of a backend.
755 756 757 758 759 760 761 762 763 764 765 766 767 768 |
# File 'lib/google/apis/firebaseapphosting_v1/service.rb', line 755 def list_project_location_backend_domains(parent, filter: nil, order_by: nil, page_size: nil, page_token: nil, show_deleted: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+parent}/domains', ) command.response_representation = Google::Apis::FirebaseapphostingV1::ListDomainsResponse::Representation command.response_class = Google::Apis::FirebaseapphostingV1::ListDomainsResponse command.params['parent'] = parent unless parent.nil? command.query['filter'] = filter unless filter.nil? command.query['orderBy'] = order_by unless order_by.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['showDeleted'] = show_deleted unless show_deleted.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_project_location_backend_rollouts(parent, filter: nil, order_by: nil, page_size: nil, page_token: nil, show_deleted: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::FirebaseapphostingV1::ListRolloutsResponse
Lists rollouts for a backend.
951 952 953 954 955 956 957 958 959 960 961 962 963 964 |
# File 'lib/google/apis/firebaseapphosting_v1/service.rb', line 951 def list_project_location_backend_rollouts(parent, filter: nil, order_by: nil, page_size: nil, page_token: nil, show_deleted: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+parent}/rollouts', ) command.response_representation = Google::Apis::FirebaseapphostingV1::ListRolloutsResponse::Representation command.response_class = Google::Apis::FirebaseapphostingV1::ListRolloutsResponse command.params['parent'] = parent unless parent.nil? command.query['filter'] = filter unless filter.nil? command.query['orderBy'] = order_by unless order_by.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['showDeleted'] = show_deleted unless show_deleted.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_project_location_backends(parent, filter: nil, order_by: nil, page_size: nil, page_token: nil, show_deleted: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::FirebaseapphostingV1::ListBackendsResponse
Lists backends in a given project and location.
322 323 324 325 326 327 328 329 330 331 332 333 334 335 |
# File 'lib/google/apis/firebaseapphosting_v1/service.rb', line 322 def list_project_location_backends(parent, filter: nil, order_by: nil, page_size: nil, page_token: nil, show_deleted: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+parent}/backends', ) command.response_representation = Google::Apis::FirebaseapphostingV1::ListBackendsResponse::Representation command.response_class = Google::Apis::FirebaseapphostingV1::ListBackendsResponse command.params['parent'] = parent unless parent.nil? command.query['filter'] = filter unless filter.nil? command.query['orderBy'] = order_by unless order_by.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['showDeleted'] = show_deleted unless show_deleted.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_project_location_operations(name, filter: nil, page_size: nil, page_token: nil, return_partial_success: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::FirebaseapphostingV1::ListOperationsResponse
Lists operations that match the specified filter in the request. If the server
doesn't support this method, it returns UNIMPLEMENTED.
1193 1194 1195 1196 1197 1198 1199 1200 1201 1202 1203 1204 1205 |
# File 'lib/google/apis/firebaseapphosting_v1/service.rb', line 1193 def list_project_location_operations(name, filter: nil, page_size: nil, page_token: nil, return_partial_success: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+name}/operations', ) command.response_representation = Google::Apis::FirebaseapphostingV1::ListOperationsResponse::Representation command.response_class = Google::Apis::FirebaseapphostingV1::ListOperationsResponse command.params['name'] = name unless name.nil? command.query['filter'] = filter unless filter.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['returnPartialSuccess'] = return_partial_success unless return_partial_success.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_project_locations(name, extra_location_types: nil, filter: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::FirebaseapphostingV1::ListLocationsResponse
Lists information about the supported locations for this service. This method
lists locations based on the resource scope provided in the [
ListLocationsRequest.name] field: * Global locations: If name is empty,
the method lists the public locations available to all projects. * Project-
specific locations: If name follows the format projects/project`, the
method lists locations visible to that specific project. This includes public,
private, or other project-specific locations enabled for the project. For gRPC
and client library implementations, the resource name is passed as thename`
field. For direct service calls, the resource name is incorporated into the
request path based on the specific service implementation and version.
132 133 134 135 136 137 138 139 140 141 142 143 144 |
# File 'lib/google/apis/firebaseapphosting_v1/service.rb', line 132 def list_project_locations(name, extra_location_types: nil, filter: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+name}/locations', ) command.response_representation = Google::Apis::FirebaseapphostingV1::ListLocationsResponse::Representation command.response_class = Google::Apis::FirebaseapphostingV1::ListLocationsResponse command.params['name'] = name unless name.nil? command.query['extraLocationTypes'] = extra_location_types unless extra_location_types.nil? command.query['filter'] = filter unless filter.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#patch_project_location_backend(name, backend_object = nil, allow_missing: nil, request_id: nil, update_mask: nil, validate_only: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::FirebaseapphostingV1::Operation
Updates the information for a single backend.
382 383 384 385 386 387 388 389 390 391 392 393 394 395 396 |
# File 'lib/google/apis/firebaseapphosting_v1/service.rb', line 382 def patch_project_location_backend(name, backend_object = nil, allow_missing: nil, request_id: nil, update_mask: nil, validate_only: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:patch, 'v1/{+name}', ) command.request_representation = Google::Apis::FirebaseapphostingV1::Backend::Representation command.request_object = backend_object command.response_representation = Google::Apis::FirebaseapphostingV1::Operation::Representation command.response_class = Google::Apis::FirebaseapphostingV1::Operation command.params['name'] = name unless name.nil? command.query['allowMissing'] = allow_missing unless allow_missing.nil? command.query['requestId'] = request_id unless request_id.nil? command.query['updateMask'] = update_mask unless update_mask.nil? command.query['validateOnly'] = validate_only unless validate_only.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#patch_project_location_backend_domain(name, domain_object = nil, allow_missing: nil, request_id: nil, update_mask: nil, validate_only: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::FirebaseapphostingV1::Operation
Updates the information for a single domain.
815 816 817 818 819 820 821 822 823 824 825 826 827 828 829 |
# File 'lib/google/apis/firebaseapphosting_v1/service.rb', line 815 def patch_project_location_backend_domain(name, domain_object = nil, allow_missing: nil, request_id: nil, update_mask: nil, validate_only: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:patch, 'v1/{+name}', ) command.request_representation = Google::Apis::FirebaseapphostingV1::Domain::Representation command.request_object = domain_object command.response_representation = Google::Apis::FirebaseapphostingV1::Operation::Representation command.response_class = Google::Apis::FirebaseapphostingV1::Operation command.params['name'] = name unless name.nil? command.query['allowMissing'] = allow_missing unless allow_missing.nil? command.query['requestId'] = request_id unless request_id.nil? command.query['updateMask'] = update_mask unless update_mask.nil? command.query['validateOnly'] = validate_only unless validate_only.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#patch_project_location_backend_traffic(name, traffic_object = nil, request_id: nil, update_mask: nil, validate_only: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::FirebaseapphostingV1::Operation
Updates a backend's traffic.
1039 1040 1041 1042 1043 1044 1045 1046 1047 1048 1049 1050 1051 1052 |
# File 'lib/google/apis/firebaseapphosting_v1/service.rb', line 1039 def patch_project_location_backend_traffic(name, traffic_object = nil, request_id: nil, update_mask: nil, validate_only: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:patch, 'v1/{+name}', ) command.request_representation = Google::Apis::FirebaseapphostingV1::Traffic::Representation command.request_object = traffic_object command.response_representation = Google::Apis::FirebaseapphostingV1::Operation::Representation command.response_class = Google::Apis::FirebaseapphostingV1::Operation command.params['name'] = name unless name.nil? command.query['requestId'] = request_id unless request_id.nil? command.query['updateMask'] = update_mask unless update_mask.nil? command.query['validateOnly'] = validate_only unless validate_only.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |