Class: Google::Apis::FirebaseapphostingV1::ListBackendsResponse
- Inherits:
-
Object
- Object
- Google::Apis::FirebaseapphostingV1::ListBackendsResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/firebaseapphosting_v1/classes.rb,
lib/google/apis/firebaseapphosting_v1/representations.rb,
lib/google/apis/firebaseapphosting_v1/representations.rb
Overview
Message for response to list backends
Instance Attribute Summary collapse
-
#backends ⇒ Array<Google::Apis::FirebaseapphostingV1::Backend>
The list of backends Corresponds to the JSON property
backends. -
#next_page_token ⇒ String
A token identifying the next page of results the server should return.
-
#unreachable ⇒ Array<String>
Locations that could not be reached.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ListBackendsResponse
constructor
A new instance of ListBackendsResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ListBackendsResponse
Returns a new instance of ListBackendsResponse.
1109 1110 1111 |
# File 'lib/google/apis/firebaseapphosting_v1/classes.rb', line 1109 def initialize(**args) update!(**args) end |
Instance Attribute Details
#backends ⇒ Array<Google::Apis::FirebaseapphostingV1::Backend>
The list of backends
Corresponds to the JSON property backends
1097 1098 1099 |
# File 'lib/google/apis/firebaseapphosting_v1/classes.rb', line 1097 def backends @backends end |
#next_page_token ⇒ String
A token identifying the next page of results the server should return.
Corresponds to the JSON property nextPageToken
1102 1103 1104 |
# File 'lib/google/apis/firebaseapphosting_v1/classes.rb', line 1102 def next_page_token @next_page_token end |
#unreachable ⇒ Array<String>
Locations that could not be reached.
Corresponds to the JSON property unreachable
1107 1108 1109 |
# File 'lib/google/apis/firebaseapphosting_v1/classes.rb', line 1107 def unreachable @unreachable end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1114 1115 1116 1117 1118 |
# File 'lib/google/apis/firebaseapphosting_v1/classes.rb', line 1114 def update!(**args) @backends = args[:backends] if args.key?(:backends) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @unreachable = args[:unreachable] if args.key?(:unreachable) end |