Class: Google::Apis::FirebaseapphostingV1::ListBuildsResponse
- Inherits:
-
Object
- Object
- Google::Apis::FirebaseapphostingV1::ListBuildsResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/firebaseapphosting_v1/classes.rb,
lib/google/apis/firebaseapphosting_v1/representations.rb,
lib/google/apis/firebaseapphosting_v1/representations.rb
Overview
Message for response to list builds.
Instance Attribute Summary collapse
-
#builds ⇒ Array<Google::Apis::FirebaseapphostingV1::Build>
The list of builds.
-
#next_page_token ⇒ String
A token identifying the next page of results the server should return.
-
#unreachable ⇒ Array<String>
Locations that could not be reached.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ListBuildsResponse
constructor
A new instance of ListBuildsResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ListBuildsResponse
Returns a new instance of ListBuildsResponse.
1140 1141 1142 |
# File 'lib/google/apis/firebaseapphosting_v1/classes.rb', line 1140 def initialize(**args) update!(**args) end |
Instance Attribute Details
#builds ⇒ Array<Google::Apis::FirebaseapphostingV1::Build>
The list of builds.
Corresponds to the JSON property builds
1128 1129 1130 |
# File 'lib/google/apis/firebaseapphosting_v1/classes.rb', line 1128 def builds @builds end |
#next_page_token ⇒ String
A token identifying the next page of results the server should return.
Corresponds to the JSON property nextPageToken
1133 1134 1135 |
# File 'lib/google/apis/firebaseapphosting_v1/classes.rb', line 1133 def next_page_token @next_page_token end |
#unreachable ⇒ Array<String>
Locations that could not be reached.
Corresponds to the JSON property unreachable
1138 1139 1140 |
# File 'lib/google/apis/firebaseapphosting_v1/classes.rb', line 1138 def unreachable @unreachable end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1145 1146 1147 1148 1149 |
# File 'lib/google/apis/firebaseapphosting_v1/classes.rb', line 1145 def update!(**args) @builds = args[:builds] if args.key?(:builds) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @unreachable = args[:unreachable] if args.key?(:unreachable) end |