Class: Google::Apis::FirebaseapphostingV1::ListRolloutsResponse
- Inherits:
-
Object
- Object
- Google::Apis::FirebaseapphostingV1::ListRolloutsResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/firebaseapphosting_v1/classes.rb,
lib/google/apis/firebaseapphosting_v1/representations.rb,
lib/google/apis/firebaseapphosting_v1/representations.rb
Overview
Message for response to list rollouts.
Instance Attribute Summary collapse
-
#next_page_token ⇒ String
A token identifying the next page of results the server should return.
-
#rollouts ⇒ Array<Google::Apis::FirebaseapphostingV1::Rollout>
The list of rollouts.
-
#unreachable ⇒ Array<String>
Locations that could not be reached.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ListRolloutsResponse
constructor
A new instance of ListRolloutsResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ListRolloutsResponse
Returns a new instance of ListRolloutsResponse.
1262 1263 1264 |
# File 'lib/google/apis/firebaseapphosting_v1/classes.rb', line 1262 def initialize(**args) update!(**args) end |
Instance Attribute Details
#next_page_token ⇒ String
A token identifying the next page of results the server should return.
Corresponds to the JSON property nextPageToken
1250 1251 1252 |
# File 'lib/google/apis/firebaseapphosting_v1/classes.rb', line 1250 def next_page_token @next_page_token end |
#rollouts ⇒ Array<Google::Apis::FirebaseapphostingV1::Rollout>
The list of rollouts.
Corresponds to the JSON property rollouts
1255 1256 1257 |
# File 'lib/google/apis/firebaseapphosting_v1/classes.rb', line 1255 def rollouts @rollouts end |
#unreachable ⇒ Array<String>
Locations that could not be reached.
Corresponds to the JSON property unreachable
1260 1261 1262 |
# File 'lib/google/apis/firebaseapphosting_v1/classes.rb', line 1260 def unreachable @unreachable end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1267 1268 1269 1270 1271 |
# File 'lib/google/apis/firebaseapphosting_v1/classes.rb', line 1267 def update!(**args) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @rollouts = args[:rollouts] if args.key?(:rollouts) @unreachable = args[:unreachable] if args.key?(:unreachable) end |