Class: Google::Apis::FirebaseapphostingV1::LiveMigrationStep

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/firebaseapphosting_v1/classes.rb,
lib/google/apis/firebaseapphosting_v1/representations.rb,
lib/google/apis/firebaseapphosting_v1/representations.rb

Overview

A set of updates including ACME challenges and DNS records that allow App Hosting to create an SSL certificate and establish project ownership for your domain name before you direct traffic to App Hosting servers. Use these updates to facilitate zero downtime migrations to App Hosting from other services. After you've made the recommended updates, check your custom domain' s ownershipState and certState. To avoid downtime, they should be OWNERSHIP_ACTIVE and CERT_ACTIVE, respectively, before you update your A and AAAA records.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ LiveMigrationStep

Returns a new instance of LiveMigrationStep.



1310
1311
1312
# File 'lib/google/apis/firebaseapphosting_v1/classes.rb', line 1310

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#dns_updatesArray<Google::Apis::FirebaseapphostingV1::DnsUpdates>

Output only. DNS updates to facilitate your domain's zero-downtime migration to App Hosting. Corresponds to the JSON property dnsUpdates



1289
1290
1291
# File 'lib/google/apis/firebaseapphosting_v1/classes.rb', line 1289

def dns_updates
  @dns_updates
end

#issuesArray<Google::Apis::FirebaseapphostingV1::Status>

Output only. Issues that prevent the current step from completing. Corresponds to the JSON property issues



1294
1295
1296
# File 'lib/google/apis/firebaseapphosting_v1/classes.rb', line 1294

def issues
  @issues
end

#relevant_domain_statesArray<String>

Output only. One or more states from the CustomDomainStatus of the migrating domain that this step is attempting to make ACTIVE. For example, if the step is attempting to mint an SSL certificate, this field will include CERT_STATE. Corresponds to the JSON property relevantDomainStates

Returns:

  • (Array<String>)


1301
1302
1303
# File 'lib/google/apis/firebaseapphosting_v1/classes.rb', line 1301

def relevant_domain_states
  @relevant_domain_states
end

#step_stateString

Output only. The state of the live migration step, indicates whether you should work to complete the step now, in the future, or have already completed it. Corresponds to the JSON property stepState

Returns:

  • (String)


1308
1309
1310
# File 'lib/google/apis/firebaseapphosting_v1/classes.rb', line 1308

def step_state
  @step_state
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1315
1316
1317
1318
1319
1320
# File 'lib/google/apis/firebaseapphosting_v1/classes.rb', line 1315

def update!(**args)
  @dns_updates = args[:dns_updates] if args.key?(:dns_updates)
  @issues = args[:issues] if args.key?(:issues)
  @relevant_domain_states = args[:relevant_domain_states] if args.key?(:relevant_domain_states)
  @step_state = args[:step_state] if args.key?(:step_state)
end