Class: Google::Apis::FirebaseapphostingV1::OperationMetadata

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/firebaseapphosting_v1/classes.rb,
lib/google/apis/firebaseapphosting_v1/representations.rb,
lib/google/apis/firebaseapphosting_v1/representations.rb

Overview

Represents the metadata of a long-running operation.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ OperationMetadata

Returns a new instance of OperationMetadata.



1495
1496
1497
# File 'lib/google/apis/firebaseapphosting_v1/classes.rb', line 1495

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#api_versionString

Output only. API version used to start the operation. Corresponds to the JSON property apiVersion

Returns:

  • (String)


1459
1460
1461
# File 'lib/google/apis/firebaseapphosting_v1/classes.rb', line 1459

def api_version
  @api_version
end

#create_timeString

Output only. The time the operation was created. Corresponds to the JSON property createTime

Returns:

  • (String)


1464
1465
1466
# File 'lib/google/apis/firebaseapphosting_v1/classes.rb', line 1464

def create_time
  @create_time
end

#end_timeString

Output only. The time the operation finished running. Corresponds to the JSON property endTime

Returns:

  • (String)


1469
1470
1471
# File 'lib/google/apis/firebaseapphosting_v1/classes.rb', line 1469

def end_time
  @end_time
end

#requested_cancellationBoolean Also known as: requested_cancellation?

Output only. Identifies whether the user has requested cancellation of the operation. Operations that have been cancelled successfully have Operation. error value with a google.rpc.Status.code of 1, corresponding to Code. CANCELLED. Corresponds to the JSON property requestedCancellation

Returns:

  • (Boolean)


1477
1478
1479
# File 'lib/google/apis/firebaseapphosting_v1/classes.rb', line 1477

def requested_cancellation
  @requested_cancellation
end

#status_messageString

Output only. Human-readable status of the operation, if any. Corresponds to the JSON property statusMessage

Returns:

  • (String)


1483
1484
1485
# File 'lib/google/apis/firebaseapphosting_v1/classes.rb', line 1483

def status_message
  @status_message
end

#targetString

Output only. Server-defined resource path for the target of the operation. Corresponds to the JSON property target

Returns:

  • (String)


1488
1489
1490
# File 'lib/google/apis/firebaseapphosting_v1/classes.rb', line 1488

def target
  @target
end

#verbString

Output only. Name of the verb executed by the operation. Corresponds to the JSON property verb

Returns:

  • (String)


1493
1494
1495
# File 'lib/google/apis/firebaseapphosting_v1/classes.rb', line 1493

def verb
  @verb
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1500
1501
1502
1503
1504
1505
1506
1507
1508
# File 'lib/google/apis/firebaseapphosting_v1/classes.rb', line 1500

def update!(**args)
  @api_version = args[:api_version] if args.key?(:api_version)
  @create_time = args[:create_time] if args.key?(:create_time)
  @end_time = args[:end_time] if args.key?(:end_time)
  @requested_cancellation = args[:requested_cancellation] if args.key?(:requested_cancellation)
  @status_message = args[:status_message] if args.key?(:status_message)
  @target = args[:target] if args.key?(:target)
  @verb = args[:verb] if args.key?(:verb)
end