Class: Google::Apis::FirebaseapphostingV1::Redirect

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/firebaseapphosting_v1/classes.rb,
lib/google/apis/firebaseapphosting_v1/representations.rb,
lib/google/apis/firebaseapphosting_v1/representations.rb

Overview

Specifies redirect behavior for a domain.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Redirect

Returns a new instance of Redirect.



1553
1554
1555
# File 'lib/google/apis/firebaseapphosting_v1/classes.rb', line 1553

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#statusFixnum

Optional. The status code to use in a redirect response. Must be a valid HTTP 3XX status code. Defaults to 302 if not present. Corresponds to the JSON property status

Returns:

  • (Fixnum)


1544
1545
1546
# File 'lib/google/apis/firebaseapphosting_v1/classes.rb', line 1544

def status
  @status
end

#uriString

Required. The URI of the redirect's intended destination. This URI will be prepended to the original request path. URI without a scheme are assumed to be HTTPS. Corresponds to the JSON property uri

Returns:

  • (String)


1551
1552
1553
# File 'lib/google/apis/firebaseapphosting_v1/classes.rb', line 1551

def uri
  @uri
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1558
1559
1560
1561
# File 'lib/google/apis/firebaseapphosting_v1/classes.rb', line 1558

def update!(**args)
  @status = args[:status] if args.key?(:status)
  @uri = args[:uri] if args.key?(:uri)
end