Class: Google::Apis::FirebaseapphostingV1::Rollout

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/firebaseapphosting_v1/classes.rb,
lib/google/apis/firebaseapphosting_v1/representations.rb,
lib/google/apis/firebaseapphosting_v1/representations.rb

Overview

A single rollout of a build for a backend.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Rollout

Returns a new instance of Rollout.



1647
1648
1649
# File 'lib/google/apis/firebaseapphosting_v1/classes.rb', line 1647

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#annotationsHash<String,String>

Optional. Unstructured key value map that may be set by external tools to store and arbitrary metadata. They are not queryable and should be preserved when modifying objects. Corresponds to the JSON property annotations

Returns:

  • (Hash<String,String>)


1573
1574
1575
# File 'lib/google/apis/firebaseapphosting_v1/classes.rb', line 1573

def annotations
  @annotations
end

#buildString

Required. Immutable. The name of a build that already exists. It doesn't have to be built; a rollout will wait for a build to be ready before updating traffic. Corresponds to the JSON property build

Returns:

  • (String)


1580
1581
1582
# File 'lib/google/apis/firebaseapphosting_v1/classes.rb', line 1580

def build
  @build
end

#create_timeString

Output only. Time at which the rollout was created. Corresponds to the JSON property createTime

Returns:

  • (String)


1585
1586
1587
# File 'lib/google/apis/firebaseapphosting_v1/classes.rb', line 1585

def create_time
  @create_time
end

#delete_timeString

Output only. Time at which the rollout was deleted. Corresponds to the JSON property deleteTime

Returns:

  • (String)


1590
1591
1592
# File 'lib/google/apis/firebaseapphosting_v1/classes.rb', line 1590

def delete_time
  @delete_time
end

#display_nameString

Optional. Human-readable name. 63 character limit. Corresponds to the JSON property displayName

Returns:

  • (String)


1595
1596
1597
# File 'lib/google/apis/firebaseapphosting_v1/classes.rb', line 1595

def display_name
  @display_name
end

#errorGoogle::Apis::FirebaseapphostingV1::Status

The Status type defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs. It is used by gRPC. Each Status message contains three pieces of data: error code, error message, and error details. You can find out more about this error model and how to work with it in the API Design Guide. Corresponds to the JSON property error



1605
1606
1607
# File 'lib/google/apis/firebaseapphosting_v1/classes.rb', line 1605

def error
  @error
end

#etagString

Output only. Server-computed checksum based on other values; may be sent on update or delete to ensure operation is done on expected resource. Corresponds to the JSON property etag

Returns:

  • (String)


1611
1612
1613
# File 'lib/google/apis/firebaseapphosting_v1/classes.rb', line 1611

def etag
  @etag
end

#labelsHash<String,String>

Optional. Unstructured key value map that can be used to organize and categorize objects. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


1617
1618
1619
# File 'lib/google/apis/firebaseapphosting_v1/classes.rb', line 1617

def labels
  @labels
end

#nameString

Identifier. The resource name of the rollout. Format: projects/project/ locations/locationId/backends/backendId/rollouts/rolloutId`. Corresponds to the JSON propertyname`

Returns:

  • (String)


1623
1624
1625
# File 'lib/google/apis/firebaseapphosting_v1/classes.rb', line 1623

def name
  @name
end

#reconcilingBoolean Also known as: reconciling?

Output only. A field that, if true, indicates that the Rollout currently has an LRO. Corresponds to the JSON property reconciling

Returns:

  • (Boolean)


1629
1630
1631
# File 'lib/google/apis/firebaseapphosting_v1/classes.rb', line 1629

def reconciling
  @reconciling
end

#stateString

Output only. The state of the rollout. Corresponds to the JSON property state

Returns:

  • (String)


1635
1636
1637
# File 'lib/google/apis/firebaseapphosting_v1/classes.rb', line 1635

def state
  @state
end

#uidString

Output only. System-assigned, unique identifier. Corresponds to the JSON property uid

Returns:

  • (String)


1640
1641
1642
# File 'lib/google/apis/firebaseapphosting_v1/classes.rb', line 1640

def uid
  @uid
end

#update_timeString

Output only. Time at which the rollout was last updated. Corresponds to the JSON property updateTime

Returns:

  • (String)


1645
1646
1647
# File 'lib/google/apis/firebaseapphosting_v1/classes.rb', line 1645

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1652
1653
1654
1655
1656
1657
1658
1659
1660
1661
1662
1663
1664
1665
1666
# File 'lib/google/apis/firebaseapphosting_v1/classes.rb', line 1652

def update!(**args)
  @annotations = args[:annotations] if args.key?(:annotations)
  @build = args[:build] if args.key?(:build)
  @create_time = args[:create_time] if args.key?(:create_time)
  @delete_time = args[:delete_time] if args.key?(:delete_time)
  @display_name = args[:display_name] if args.key?(:display_name)
  @error = args[:error] if args.key?(:error)
  @etag = args[:etag] if args.key?(:etag)
  @labels = args[:labels] if args.key?(:labels)
  @name = args[:name] if args.key?(:name)
  @reconciling = args[:reconciling] if args.key?(:reconciling)
  @state = args[:state] if args.key?(:state)
  @uid = args[:uid] if args.key?(:uid)
  @update_time = args[:update_time] if args.key?(:update_time)
end