Class: Google::Apis::FirebaseapphostingV1::SourceUserMetadata

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/firebaseapphosting_v1/classes.rb,
lib/google/apis/firebaseapphosting_v1/representations.rb,
lib/google/apis/firebaseapphosting_v1/representations.rb

Overview

Deprecated: Not used. Metadata for the user who started the build.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SourceUserMetadata

Returns a new instance of SourceUserMetadata.



1851
1852
1853
# File 'lib/google/apis/firebaseapphosting_v1/classes.rb', line 1851

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#display_nameString

Output only. Deprecated: Not used. The user-chosen displayname. May be empty. Corresponds to the JSON property displayName

Returns:

  • (String)


1837
1838
1839
# File 'lib/google/apis/firebaseapphosting_v1/classes.rb', line 1837

def display_name
  @display_name
end

#emailString

Output only. Deprecated: Not used. The account email linked to the EUC that created the build. May be a service account or other robot account. Corresponds to the JSON property email

Returns:

  • (String)


1843
1844
1845
# File 'lib/google/apis/firebaseapphosting_v1/classes.rb', line 1843

def email
  @email
end

#image_uriString

Output only. Deprecated: Not used. The URI of a profile photo associated with the user who created the build. Corresponds to the JSON property imageUri

Returns:

  • (String)


1849
1850
1851
# File 'lib/google/apis/firebaseapphosting_v1/classes.rb', line 1849

def image_uri
  @image_uri
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1856
1857
1858
1859
1860
# File 'lib/google/apis/firebaseapphosting_v1/classes.rb', line 1856

def update!(**args)
  @display_name = args[:display_name] if args.key?(:display_name)
  @email = args[:email] if args.key?(:email)
  @image_uri = args[:image_uri] if args.key?(:image_uri)
end