Class: Google::Apis::FirebaseapphostingV1::Traffic

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/firebaseapphosting_v1/classes.rb,
lib/google/apis/firebaseapphosting_v1/representations.rb,
lib/google/apis/firebaseapphosting_v1/representations.rb

Overview

Controls traffic configuration for the backend.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Traffic

Returns a new instance of Traffic.



1968
1969
1970
# File 'lib/google/apis/firebaseapphosting_v1/classes.rb', line 1968

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#annotationsHash<String,String>

Optional. Unstructured key value map that may be set by external tools to store and arbitrary metadata. They are not queryable and should be preserved when modifying objects. Corresponds to the JSON property annotations

Returns:

  • (Hash<String,String>)


1911
1912
1913
# File 'lib/google/apis/firebaseapphosting_v1/classes.rb', line 1911

def annotations
  @annotations
end

#create_timeString

Output only. Time at which the backend was created. Corresponds to the JSON property createTime

Returns:

  • (String)


1916
1917
1918
# File 'lib/google/apis/firebaseapphosting_v1/classes.rb', line 1916

def create_time
  @create_time
end

#currentGoogle::Apis::FirebaseapphostingV1::TrafficSet

A list of traffic splits that together represent where traffic is being routed. Corresponds to the JSON property current



1921
1922
1923
# File 'lib/google/apis/firebaseapphosting_v1/classes.rb', line 1921

def current
  @current
end

#etagString

Output only. Server-computed checksum based on other values; may be sent on update or delete to ensure operation is done on expected resource. Corresponds to the JSON property etag

Returns:

  • (String)


1927
1928
1929
# File 'lib/google/apis/firebaseapphosting_v1/classes.rb', line 1927

def etag
  @etag
end

#labelsHash<String,String>

Optional. Unstructured key value map that can be used to organize and categorize objects. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


1933
1934
1935
# File 'lib/google/apis/firebaseapphosting_v1/classes.rb', line 1933

def labels
  @labels
end

#nameString

Identifier. The resource name of the backend's traffic. Format: projects/ project/locations/locationId/backends/backendId/traffic. Corresponds to the JSON property name

Returns:

  • (String)


1939
1940
1941
# File 'lib/google/apis/firebaseapphosting_v1/classes.rb', line 1939

def name
  @name
end

#reconcilingBoolean Also known as: reconciling?

Output only. A field that, if true, indicates that the system is working to make the backend's current match the requested target list. Corresponds to the JSON property reconciling

Returns:

  • (Boolean)


1945
1946
1947
# File 'lib/google/apis/firebaseapphosting_v1/classes.rb', line 1945

def reconciling
  @reconciling
end

#rollout_policyGoogle::Apis::FirebaseapphostingV1::RolloutPolicy

The policy for how automatic builds and rollouts are triggered and rolled out. Corresponds to the JSON property rolloutPolicy



1951
1952
1953
# File 'lib/google/apis/firebaseapphosting_v1/classes.rb', line 1951

def rollout_policy
  @rollout_policy
end

#targetGoogle::Apis::FirebaseapphostingV1::TrafficSet

A list of traffic splits that together represent where traffic is being routed. Corresponds to the JSON property target



1956
1957
1958
# File 'lib/google/apis/firebaseapphosting_v1/classes.rb', line 1956

def target
  @target
end

#uidString

Output only. System-assigned, unique identifier. Corresponds to the JSON property uid

Returns:

  • (String)


1961
1962
1963
# File 'lib/google/apis/firebaseapphosting_v1/classes.rb', line 1961

def uid
  @uid
end

#update_timeString

Output only. Time at which the backend was last updated. Corresponds to the JSON property updateTime

Returns:

  • (String)


1966
1967
1968
# File 'lib/google/apis/firebaseapphosting_v1/classes.rb', line 1966

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1973
1974
1975
1976
1977
1978
1979
1980
1981
1982
1983
1984
1985
# File 'lib/google/apis/firebaseapphosting_v1/classes.rb', line 1973

def update!(**args)
  @annotations = args[:annotations] if args.key?(:annotations)
  @create_time = args[:create_time] if args.key?(:create_time)
  @current = args[:current] if args.key?(:current)
  @etag = args[:etag] if args.key?(:etag)
  @labels = args[:labels] if args.key?(:labels)
  @name = args[:name] if args.key?(:name)
  @reconciling = args[:reconciling] if args.key?(:reconciling)
  @rollout_policy = args[:rollout_policy] if args.key?(:rollout_policy)
  @target = args[:target] if args.key?(:target)
  @uid = args[:uid] if args.key?(:uid)
  @update_time = args[:update_time] if args.key?(:update_time)
end