Class: Google::Apis::FirebaseapphostingV1::UserMetadata

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/firebaseapphosting_v1/classes.rb,
lib/google/apis/firebaseapphosting_v1/representations.rb,
lib/google/apis/firebaseapphosting_v1/representations.rb

Overview

Version control metadata for a user associated with a resolved codebase. Currently assumes a Git user.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ UserMetadata

Returns a new instance of UserMetadata.



2054
2055
2056
# File 'lib/google/apis/firebaseapphosting_v1/classes.rb', line 2054

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#display_nameString

Output only. The 'name' field in a Git user's git.config. Required by Git. Corresponds to the JSON property displayName

Returns:

  • (String)


2041
2042
2043
# File 'lib/google/apis/firebaseapphosting_v1/classes.rb', line 2041

def display_name
  @display_name
end

#emailString

Output only. The 'email' field in a Git user's git.config, if available. Corresponds to the JSON property email

Returns:

  • (String)


2046
2047
2048
# File 'lib/google/apis/firebaseapphosting_v1/classes.rb', line 2046

def email
  @email
end

#image_uriString

Output only. The URI of an image file associated with the user's account in an external source control provider, if available. Corresponds to the JSON property imageUri

Returns:

  • (String)


2052
2053
2054
# File 'lib/google/apis/firebaseapphosting_v1/classes.rb', line 2052

def image_uri
  @image_uri
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2059
2060
2061
2062
2063
# File 'lib/google/apis/firebaseapphosting_v1/classes.rb', line 2059

def update!(**args)
  @display_name = args[:display_name] if args.key?(:display_name)
  @email = args[:email] if args.key?(:email)
  @image_uri = args[:image_uri] if args.key?(:image_uri)
end