Class: Google::Apis::FirebaseapphostingV1::ArchiveSource
- Inherits:
-
Object
- Object
- Google::Apis::FirebaseapphostingV1::ArchiveSource
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/firebaseapphosting_v1/classes.rb,
lib/google/apis/firebaseapphosting_v1/representations.rb,
lib/google/apis/firebaseapphosting_v1/representations.rb
Overview
The URI of an storage archive or a signed URL to use as the build source.
Instance Attribute Summary collapse
-
#author ⇒ Google::Apis::FirebaseapphostingV1::SourceUserMetadata
Deprecated: Not used.
-
#description ⇒ String
Optional.
-
#external_signed_uri ⇒ String
Signed URL to an archive in a storage bucket.
-
#root_directory ⇒ String
Optional.
-
#user_storage_uri ⇒ String
URI to an archive in Cloud Storage.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ArchiveSource
constructor
A new instance of ArchiveSource.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ArchiveSource
Returns a new instance of ArchiveSource.
60 61 62 |
# File 'lib/google/apis/firebaseapphosting_v1/classes.rb', line 60 def initialize(**args) update!(**args) end |
Instance Attribute Details
#author ⇒ Google::Apis::FirebaseapphostingV1::SourceUserMetadata
Deprecated: Not used. Metadata for the user who started the build.
Corresponds to the JSON property author
32 33 34 |
# File 'lib/google/apis/firebaseapphosting_v1/classes.rb', line 32 def @author end |
#description ⇒ String
Optional. An optional message that describes the uploaded version of the
source code.
Corresponds to the JSON property description
38 39 40 |
# File 'lib/google/apis/firebaseapphosting_v1/classes.rb', line 38 def description @description end |
#external_signed_uri ⇒ String
Signed URL to an archive in a storage bucket.
Corresponds to the JSON property externalSignedUri
43 44 45 |
# File 'lib/google/apis/firebaseapphosting_v1/classes.rb', line 43 def external_signed_uri @external_signed_uri end |
#root_directory ⇒ String
Optional. The directory relative to the root of the archive to use as the root
for the deployed web app. Defaults to use the root of the repository if not
provided. If deploying a monorepo, this should be the directory that contains the package.
json or apphosting.yaml file.
Corresponds to the JSON property rootDirectory
52 53 54 |
# File 'lib/google/apis/firebaseapphosting_v1/classes.rb', line 52 def root_directory @root_directory end |
#user_storage_uri ⇒ String
URI to an archive in Cloud Storage. The object must be a zipped (.zip) or
gzipped archive file (.tar.gz) containing source to deploy.
Corresponds to the JSON property userStorageUri
58 59 60 |
# File 'lib/google/apis/firebaseapphosting_v1/classes.rb', line 58 def user_storage_uri @user_storage_uri end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
65 66 67 68 69 70 71 |
# File 'lib/google/apis/firebaseapphosting_v1/classes.rb', line 65 def update!(**args) @author = args[:author] if args.key?(:author) @description = args[:description] if args.key?(:description) @external_signed_uri = args[:external_signed_uri] if args.key?(:external_signed_uri) @root_directory = args[:root_directory] if args.key?(:root_directory) @user_storage_uri = args[:user_storage_uri] if args.key?(:user_storage_uri) end |