Class: Google::Apis::FirebaseapphostingV1::Build
- Inherits:
-
Object
- Object
- Google::Apis::FirebaseapphostingV1::Build
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/firebaseapphosting_v1/classes.rb,
lib/google/apis/firebaseapphosting_v1/representations.rb,
lib/google/apis/firebaseapphosting_v1/representations.rb
Overview
A single build for a backend, at a specific point codebase reference tag and point in time. Encapsulates several resources, including an Artifact Registry container image, a Cloud Build invocation that built the image, and the Cloud Run revision that uses that image.
Instance Attribute Summary collapse
-
#annotations ⇒ Hash<String,String>
Optional.
-
#build_logs_uri ⇒ String
Output only.
-
#config ⇒ Google::Apis::FirebaseapphostingV1::Config
Additional configuration of the backend for this build.
-
#create_time ⇒ String
Output only.
-
#delete_time ⇒ String
Output only.
-
#display_name ⇒ String
Optional.
-
#environment ⇒ String
Output only.
-
#errors ⇒ Array<Google::Apis::FirebaseapphostingV1::Error>
Output only.
-
#etag ⇒ String
Output only.
-
#image ⇒ String
Output only.
-
#labels ⇒ Hash<String,String>
Optional.
-
#name ⇒ String
Identifier.
-
#reconciling ⇒ Boolean
(also: #reconciling?)
Output only.
-
#source ⇒ Google::Apis::FirebaseapphostingV1::BuildSource
The source for the build.
-
#state ⇒ String
Output only.
-
#uid ⇒ String
Output only.
-
#update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Build
constructor
A new instance of Build.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Build
Returns a new instance of Build.
323 324 325 |
# File 'lib/google/apis/firebaseapphosting_v1/classes.rb', line 323 def initialize(**args) update!(**args) end |
Instance Attribute Details
#annotations ⇒ Hash<String,String>
Optional. Unstructured key value map that may be set by external tools to
store and arbitrary metadata. They are not queryable and should be preserved
when modifying objects.
Corresponds to the JSON property annotations
231 232 233 |
# File 'lib/google/apis/firebaseapphosting_v1/classes.rb', line 231 def annotations @annotations end |
#build_logs_uri ⇒ String
Output only. The location of the Cloud Build logs for the build process.
Corresponds to the JSON property buildLogsUri
237 238 239 |
# File 'lib/google/apis/firebaseapphosting_v1/classes.rb', line 237 def build_logs_uri @build_logs_uri end |
#config ⇒ Google::Apis::FirebaseapphostingV1::Config
Additional configuration of the backend for this build.
Corresponds to the JSON property config
242 243 244 |
# File 'lib/google/apis/firebaseapphosting_v1/classes.rb', line 242 def config @config end |
#create_time ⇒ String
Output only. Time at which the build was created.
Corresponds to the JSON property createTime
247 248 249 |
# File 'lib/google/apis/firebaseapphosting_v1/classes.rb', line 247 def create_time @create_time end |
#delete_time ⇒ String
Output only. Time at which the build was deleted.
Corresponds to the JSON property deleteTime
252 253 254 |
# File 'lib/google/apis/firebaseapphosting_v1/classes.rb', line 252 def delete_time @delete_time end |
#display_name ⇒ String
Optional. Human-readable name. 63 character limit.
Corresponds to the JSON property displayName
257 258 259 |
# File 'lib/google/apis/firebaseapphosting_v1/classes.rb', line 257 def display_name @display_name end |
#environment ⇒ String
Output only. The environment name of the backend when this build was created.
Corresponds to the JSON property environment
262 263 264 |
# File 'lib/google/apis/firebaseapphosting_v1/classes.rb', line 262 def environment @environment end |
#errors ⇒ Array<Google::Apis::FirebaseapphostingV1::Error>
Output only. A list of all errors that occurred during an App Hosting build.
Corresponds to the JSON property errors
267 268 269 |
# File 'lib/google/apis/firebaseapphosting_v1/classes.rb', line 267 def errors @errors end |
#etag ⇒ String
Output only. Server-computed checksum based on other values; may be sent on
update or delete to ensure operation is done on expected resource.
Corresponds to the JSON property etag
273 274 275 |
# File 'lib/google/apis/firebaseapphosting_v1/classes.rb', line 273 def etag @etag end |
#image ⇒ String
Output only. The Artifact Registry container image URI, used by the Cloud Run revision for this
build.
Corresponds to the JSON property image
282 283 284 |
# File 'lib/google/apis/firebaseapphosting_v1/classes.rb', line 282 def image @image end |
#labels ⇒ Hash<String,String>
Optional. Unstructured key value map that can be used to organize and
categorize objects.
Corresponds to the JSON property labels
288 289 290 |
# File 'lib/google/apis/firebaseapphosting_v1/classes.rb', line 288 def labels @labels end |
#name ⇒ String
Identifier. The resource name of the build. Format: projects/project/
locations/locationId/backends/backendId/builds/buildId`.
Corresponds to the JSON propertyname`
294 295 296 |
# File 'lib/google/apis/firebaseapphosting_v1/classes.rb', line 294 def name @name end |
#reconciling ⇒ Boolean Also known as: reconciling?
Output only. A field that, if true, indicates that the build has an ongoing
LRO.
Corresponds to the JSON property reconciling
300 301 302 |
# File 'lib/google/apis/firebaseapphosting_v1/classes.rb', line 300 def reconciling @reconciling end |
#source ⇒ Google::Apis::FirebaseapphostingV1::BuildSource
The source for the build.
Corresponds to the JSON property source
306 307 308 |
# File 'lib/google/apis/firebaseapphosting_v1/classes.rb', line 306 def source @source end |
#state ⇒ String
Output only. The state of the build.
Corresponds to the JSON property state
311 312 313 |
# File 'lib/google/apis/firebaseapphosting_v1/classes.rb', line 311 def state @state end |
#uid ⇒ String
Output only. System-assigned, unique identifier.
Corresponds to the JSON property uid
316 317 318 |
# File 'lib/google/apis/firebaseapphosting_v1/classes.rb', line 316 def uid @uid end |
#update_time ⇒ String
Output only. Time at which the build was last updated.
Corresponds to the JSON property updateTime
321 322 323 |
# File 'lib/google/apis/firebaseapphosting_v1/classes.rb', line 321 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 |
# File 'lib/google/apis/firebaseapphosting_v1/classes.rb', line 328 def update!(**args) @annotations = args[:annotations] if args.key?(:annotations) @build_logs_uri = args[:build_logs_uri] if args.key?(:build_logs_uri) @config = args[:config] if args.key?(:config) @create_time = args[:create_time] if args.key?(:create_time) @delete_time = args[:delete_time] if args.key?(:delete_time) @display_name = args[:display_name] if args.key?(:display_name) @environment = args[:environment] if args.key?(:environment) @errors = args[:errors] if args.key?(:errors) @etag = args[:etag] if args.key?(:etag) @image = args[:image] if args.key?(:image) @labels = args[:labels] if args.key?(:labels) @name = args[:name] if args.key?(:name) @reconciling = args[:reconciling] if args.key?(:reconciling) @source = args[:source] if args.key?(:source) @state = args[:state] if args.key?(:state) @uid = args[:uid] if args.key?(:uid) @update_time = args[:update_time] if args.key?(:update_time) end |