Class: Google::Apis::FirebaseapphostingV1::BuildSource
- Inherits:
-
Object
- Object
- Google::Apis::FirebaseapphostingV1::BuildSource
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/firebaseapphosting_v1/classes.rb,
lib/google/apis/firebaseapphosting_v1/representations.rb,
lib/google/apis/firebaseapphosting_v1/representations.rb
Overview
The source for the build.
Instance Attribute Summary collapse
-
#archive ⇒ Google::Apis::FirebaseapphostingV1::ArchiveSource
The URI of an storage archive or a signed URL to use as the build source.
-
#codebase ⇒ Google::Apis::FirebaseapphostingV1::CodebaseSource
A codebase source, representing the state of the codebase that the build will be created at.
-
#container ⇒ Google::Apis::FirebaseapphostingV1::ContainerSource
The URI of an Artifact Registry container image to use as the build source.
Instance Method Summary collapse
-
#initialize(**args) ⇒ BuildSource
constructor
A new instance of BuildSource.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ BuildSource
Returns a new instance of BuildSource.
371 372 373 |
# File 'lib/google/apis/firebaseapphosting_v1/classes.rb', line 371 def initialize(**args) update!(**args) end |
Instance Attribute Details
#archive ⇒ Google::Apis::FirebaseapphostingV1::ArchiveSource
The URI of an storage archive or a signed URL to use as the build source.
Corresponds to the JSON property archive
356 357 358 |
# File 'lib/google/apis/firebaseapphosting_v1/classes.rb', line 356 def archive @archive end |
#codebase ⇒ Google::Apis::FirebaseapphostingV1::CodebaseSource
A codebase source, representing the state of the codebase that the build will
be created at.
Corresponds to the JSON property codebase
362 363 364 |
# File 'lib/google/apis/firebaseapphosting_v1/classes.rb', line 362 def codebase @codebase end |
#container ⇒ Google::Apis::FirebaseapphostingV1::ContainerSource
The URI of an Artifact Registry container image to use as the build source.
Corresponds to the JSON property container
369 370 371 |
# File 'lib/google/apis/firebaseapphosting_v1/classes.rb', line 369 def container @container end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
376 377 378 379 380 |
# File 'lib/google/apis/firebaseapphosting_v1/classes.rb', line 376 def update!(**args) @archive = args[:archive] if args.key?(:archive) @codebase = args[:codebase] if args.key?(:codebase) @container = args[:container] if args.key?(:container) end |