Class: Google::Apis::FirebaseapphostingV1::Codebase
- Inherits:
-
Object
- Object
- Google::Apis::FirebaseapphostingV1::Codebase
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/firebaseapphosting_v1/classes.rb,
lib/google/apis/firebaseapphosting_v1/representations.rb,
lib/google/apis/firebaseapphosting_v1/representations.rb
Overview
The connection to an external source repository to watch for event-driven updates to the backend.
Instance Attribute Summary collapse
-
#repository ⇒ String
Required.
-
#root_directory ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Codebase
constructor
A new instance of Codebase.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Codebase
Returns a new instance of Codebase.
421 422 423 |
# File 'lib/google/apis/firebaseapphosting_v1/classes.rb', line 421 def initialize(**args) update!(**args) end |
Instance Attribute Details
#repository ⇒ String
Required. The resource name for the Developer Connect gitRepositoryLink connected to this backend, in the
format: projects/project/locations/location/connections/connection/
gitRepositoryLinks/repositoryLink`The connection for thegitRepositoryLink
must made be using the Firebase App Hosting GitHub App via the Firebase
Console.
Corresponds to the JSON propertyrepository`
410 411 412 |
# File 'lib/google/apis/firebaseapphosting_v1/classes.rb', line 410 def repository @repository end |
#root_directory ⇒ String
Optional. If repository is provided, the directory relative to the root of
the repository to use as the root for the deployed web app. Defaults to use
the root of the repository if not provided. If deploying a monorepo, this should be the directory
that contains the package.json or apphosting.yaml file.
Corresponds to the JSON property rootDirectory
419 420 421 |
# File 'lib/google/apis/firebaseapphosting_v1/classes.rb', line 419 def root_directory @root_directory end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
426 427 428 429 |
# File 'lib/google/apis/firebaseapphosting_v1/classes.rb', line 426 def update!(**args) @repository = args[:repository] if args.key?(:repository) @root_directory = args[:root_directory] if args.key?(:root_directory) end |