Class: Google::Apis::FirebaseapphostingV1::CodebaseSource
- Inherits:
-
Object
- Object
- Google::Apis::FirebaseapphostingV1::CodebaseSource
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/firebaseapphosting_v1/classes.rb,
lib/google/apis/firebaseapphosting_v1/representations.rb,
lib/google/apis/firebaseapphosting_v1/representations.rb
Overview
A codebase source, representing the state of the codebase that the build will be created at.
Instance Attribute Summary collapse
-
#author ⇒ Google::Apis::FirebaseapphostingV1::UserMetadata
Version control metadata for a user associated with a resolved codebase.
-
#branch ⇒ String
The branch in the codebase to build from, using the latest commit.
-
#commit ⇒ String
The commit in the codebase to build from.
-
#commit_message ⇒ String
Output only.
-
#commit_time ⇒ String
Output only.
-
#display_name ⇒ String
Output only.
-
#hash_prop ⇒ String
Output only.
-
#repository ⇒ String
Output only.
-
#uri ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ CodebaseSource
constructor
A new instance of CodebaseSource.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ CodebaseSource
Returns a new instance of CodebaseSource.
490 491 492 |
# File 'lib/google/apis/firebaseapphosting_v1/classes.rb', line 490 def initialize(**args) update!(**args) end |
Instance Attribute Details
#author ⇒ Google::Apis::FirebaseapphostingV1::UserMetadata
Version control metadata for a user associated with a resolved codebase.
Currently assumes a Git user.
Corresponds to the JSON property author
441 442 443 |
# File 'lib/google/apis/firebaseapphosting_v1/classes.rb', line 441 def @author end |
#branch ⇒ String
The branch in the codebase to build from, using the latest commit.
Corresponds to the JSON property branch
446 447 448 |
# File 'lib/google/apis/firebaseapphosting_v1/classes.rb', line 446 def branch @branch end |
#commit ⇒ String
The commit in the codebase to build from.
Corresponds to the JSON property commit
451 452 453 |
# File 'lib/google/apis/firebaseapphosting_v1/classes.rb', line 451 def commit @commit end |
#commit_message ⇒ String
Output only. The message of a codebase change.
Corresponds to the JSON property commitMessage
456 457 458 |
# File 'lib/google/apis/firebaseapphosting_v1/classes.rb', line 456 def @commit_message end |
#commit_time ⇒ String
Output only. The time the change was made.
Corresponds to the JSON property commitTime
461 462 463 |
# File 'lib/google/apis/firebaseapphosting_v1/classes.rb', line 461 def commit_time @commit_time end |
#display_name ⇒ String
Output only. The human-friendly name to use for this Codebase when displaying
a build. We use the first eight characters of the SHA-1 hash for GitHub.com.
Corresponds to the JSON property displayName
467 468 469 |
# File 'lib/google/apis/firebaseapphosting_v1/classes.rb', line 467 def display_name @display_name end |
#hash_prop ⇒ String
Output only. The full SHA-1 hash of a Git commit, if available.
Corresponds to the JSON property hash
472 473 474 |
# File 'lib/google/apis/firebaseapphosting_v1/classes.rb', line 472 def hash_prop @hash_prop end |
#repository ⇒ String
Output only. The resource name for the Developer Connect gitRepositoryLink used for this build, in the format:
projects/project/locations/location/connections/connection/
gitRepositoryLinks/repositoryLink`
Corresponds to the JSON propertyrepository`
481 482 483 |
# File 'lib/google/apis/firebaseapphosting_v1/classes.rb', line 481 def repository @repository end |
#uri ⇒ String
Output only. A URI linking to the codebase on an hosting provider's website.
May not be valid if the commit has been rebased or force-pushed out of
existence in the linked repository.
Corresponds to the JSON property uri
488 489 490 |
# File 'lib/google/apis/firebaseapphosting_v1/classes.rb', line 488 def uri @uri end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
495 496 497 498 499 500 501 502 503 504 505 |
# File 'lib/google/apis/firebaseapphosting_v1/classes.rb', line 495 def update!(**args) @author = args[:author] if args.key?(:author) @branch = args[:branch] if args.key?(:branch) @commit = args[:commit] if args.key?(:commit) @commit_message = args[:commit_message] if args.key?(:commit_message) @commit_time = args[:commit_time] if args.key?(:commit_time) @display_name = args[:display_name] if args.key?(:display_name) @hash_prop = args[:hash_prop] if args.key?(:hash_prop) @repository = args[:repository] if args.key?(:repository) @uri = args[:uri] if args.key?(:uri) end |