Class: Google::Apis::FirebaseapphostingV1::ContainerSource
- Inherits:
-
Object
- Object
- Google::Apis::FirebaseapphostingV1::ContainerSource
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/firebaseapphosting_v1/classes.rb,
lib/google/apis/firebaseapphosting_v1/representations.rb,
lib/google/apis/firebaseapphosting_v1/representations.rb
Overview
The URI of an Artifact Registry container image to use as the build source.
Instance Attribute Summary collapse
-
#image ⇒ String
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ContainerSource
constructor
A new instance of ContainerSource.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ContainerSource
Returns a new instance of ContainerSource.
558 559 560 |
# File 'lib/google/apis/firebaseapphosting_v1/classes.rb', line 558 def initialize(**args) update!(**args) end |
Instance Attribute Details
#image ⇒ String
Required. A URI representing a container for the backend to use.
Corresponds to the JSON property image
556 557 558 |
# File 'lib/google/apis/firebaseapphosting_v1/classes.rb', line 556 def image @image end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
563 564 565 |
# File 'lib/google/apis/firebaseapphosting_v1/classes.rb', line 563 def update!(**args) @image = args[:image] if args.key?(:image) end |