Class: Google::Apis::FirebaseapphostingV1::CustomDomainOperationMetadata
- Inherits:
-
Object
- Object
- Google::Apis::FirebaseapphostingV1::CustomDomainOperationMetadata
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/firebaseapphosting_v1/classes.rb,
lib/google/apis/firebaseapphosting_v1/representations.rb,
lib/google/apis/firebaseapphosting_v1/representations.rb
Overview
Additional metadata for operations on custom domains.
Instance Attribute Summary collapse
-
#cert_state ⇒ String
Output only.
-
#host_state ⇒ String
Output only.
-
#issues ⇒ Array<Google::Apis::FirebaseapphostingV1::Status>
Output only.
-
#live_migration_steps ⇒ Array<Google::Apis::FirebaseapphostingV1::LiveMigrationStep>
Output only.
-
#ownership_state ⇒ String
Output only.
-
#quick_setup_updates ⇒ Array<Google::Apis::FirebaseapphostingV1::DnsUpdates>
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ CustomDomainOperationMetadata
constructor
A new instance of CustomDomainOperationMetadata.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ CustomDomainOperationMetadata
Returns a new instance of CustomDomainOperationMetadata.
609 610 611 |
# File 'lib/google/apis/firebaseapphosting_v1/classes.rb', line 609 def initialize(**args) update!(**args) end |
Instance Attribute Details
#cert_state ⇒ String
Output only. The custom domain's CertState, which must be CERT_ACTIVE for
the create operations to complete.
Corresponds to the JSON property certState
576 577 578 |
# File 'lib/google/apis/firebaseapphosting_v1/classes.rb', line 576 def cert_state @cert_state end |
#host_state ⇒ String
Output only. The custom domain's HostState, which must be HOST_ACTIVE for
Create operations of the domain name this CustomDomain refers toto complete.
Corresponds to the JSON property hostState
582 583 584 |
# File 'lib/google/apis/firebaseapphosting_v1/classes.rb', line 582 def host_state @host_state end |
#issues ⇒ Array<Google::Apis::FirebaseapphostingV1::Status>
Output only. A list of issues that are currently preventing the operation from
completing. These are generally DNS-related issues encountered when querying a
domain's records or attempting to mint an SSL certificate.
Corresponds to the JSON property issues
589 590 591 |
# File 'lib/google/apis/firebaseapphosting_v1/classes.rb', line 589 def issues @issues end |
#live_migration_steps ⇒ Array<Google::Apis::FirebaseapphostingV1::LiveMigrationStep>
Output only. A list of steps that the user must complete to migrate their
domain to App Hosting without downtime.
Corresponds to the JSON property liveMigrationSteps
595 596 597 |
# File 'lib/google/apis/firebaseapphosting_v1/classes.rb', line 595 def live_migration_steps @live_migration_steps end |
#ownership_state ⇒ String
Output only. The custom domain's OwnershipState, which must be
OWNERSHIP_ACTIVE for the create operations to complete.
Corresponds to the JSON property ownershipState
601 602 603 |
# File 'lib/google/apis/firebaseapphosting_v1/classes.rb', line 601 def ownership_state @ownership_state end |
#quick_setup_updates ⇒ Array<Google::Apis::FirebaseapphostingV1::DnsUpdates>
Output only. A set of DNS record updates to perform, to allow App Hosting to
serve secure content on the domain.
Corresponds to the JSON property quickSetupUpdates
607 608 609 |
# File 'lib/google/apis/firebaseapphosting_v1/classes.rb', line 607 def quick_setup_updates @quick_setup_updates end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
614 615 616 617 618 619 620 621 |
# File 'lib/google/apis/firebaseapphosting_v1/classes.rb', line 614 def update!(**args) @cert_state = args[:cert_state] if args.key?(:cert_state) @host_state = args[:host_state] if args.key?(:host_state) @issues = args[:issues] if args.key?(:issues) @live_migration_steps = args[:live_migration_steps] if args.key?(:live_migration_steps) @ownership_state = args[:ownership_state] if args.key?(:ownership_state) @quick_setup_updates = args[:quick_setup_updates] if args.key?(:quick_setup_updates) end |