Class: Google::Apis::FirebaseapphostingV1::CustomDomainStatus
- Inherits:
-
Object
- Object
- Google::Apis::FirebaseapphostingV1::CustomDomainStatus
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/firebaseapphosting_v1/classes.rb,
lib/google/apis/firebaseapphosting_v1/representations.rb,
lib/google/apis/firebaseapphosting_v1/representations.rb
Overview
The status of a custom domain's linkage to a backend.
Instance Attribute Summary collapse
-
#cert_state ⇒ String
Output only.
-
#host_state ⇒ String
Output only.
-
#issues ⇒ Array<Google::Apis::FirebaseapphostingV1::Status>
Output only.
-
#ownership_state ⇒ String
Output only.
-
#required_dns_updates ⇒ Array<Google::Apis::FirebaseapphostingV1::DnsUpdates>
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ CustomDomainStatus
constructor
A new instance of CustomDomainStatus.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ CustomDomainStatus
Returns a new instance of CustomDomainStatus.
659 660 661 |
# File 'lib/google/apis/firebaseapphosting_v1/classes.rb', line 659 def initialize(**args) update!(**args) end |
Instance Attribute Details
#cert_state ⇒ String
Output only. Tracks SSL certificate status for the domain.
Corresponds to the JSON property certState
631 632 633 |
# File 'lib/google/apis/firebaseapphosting_v1/classes.rb', line 631 def cert_state @cert_state end |
#host_state ⇒ String
Output only. Tracks whether a custom domain is detected as appropriately
directing traffic to App Hosting.
Corresponds to the JSON property hostState
637 638 639 |
# File 'lib/google/apis/firebaseapphosting_v1/classes.rb', line 637 def host_state @host_state end |
#issues ⇒ Array<Google::Apis::FirebaseapphostingV1::Status>
Output only. A list of issues with domain configuration. Allows users to self-
correct problems with DNS records.
Corresponds to the JSON property issues
643 644 645 |
# File 'lib/google/apis/firebaseapphosting_v1/classes.rb', line 643 def issues @issues end |
#ownership_state ⇒ String
Output only. Tracks whether the backend is permitted to serve content on the
domain, based off the domain's DNS records.
Corresponds to the JSON property ownershipState
649 650 651 |
# File 'lib/google/apis/firebaseapphosting_v1/classes.rb', line 649 def ownership_state @ownership_state end |
#required_dns_updates ⇒ Array<Google::Apis::FirebaseapphostingV1::DnsUpdates>
Output only. Lists the records that must added or removed to a custom domain's
DNS in order to finish setup and start serving content. Field is present
during onboarding. Also present after onboarding if one or more of the above
states is not *_ACTIVE, indicating the domain's DNS records are in a bad state.
Corresponds to the JSON property requiredDnsUpdates
657 658 659 |
# File 'lib/google/apis/firebaseapphosting_v1/classes.rb', line 657 def required_dns_updates @required_dns_updates end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
664 665 666 667 668 669 670 |
# File 'lib/google/apis/firebaseapphosting_v1/classes.rb', line 664 def update!(**args) @cert_state = args[:cert_state] if args.key?(:cert_state) @host_state = args[:host_state] if args.key?(:host_state) @issues = args[:issues] if args.key?(:issues) @ownership_state = args[:ownership_state] if args.key?(:ownership_state) @required_dns_updates = args[:required_dns_updates] if args.key?(:required_dns_updates) end |