Class: Google::Apis::FirebaseapphostingV1::EnvironmentVariable
- Inherits:
-
Object
- Object
- Google::Apis::FirebaseapphostingV1::EnvironmentVariable
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/firebaseapphosting_v1/classes.rb,
lib/google/apis/firebaseapphosting_v1/representations.rb,
lib/google/apis/firebaseapphosting_v1/representations.rb
Overview
Environment variables for this build.
Instance Attribute Summary collapse
-
#availability ⇒ Array<String>
Optional.
-
#origin ⇒ String
Output only.
-
#origin_file_name ⇒ String
Output only.
-
#secret ⇒ String
A fully qualified secret version.
-
#value ⇒ String
A plaintext value.
-
#variable ⇒ String
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ EnvironmentVariable
constructor
A new instance of EnvironmentVariable.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ EnvironmentVariable
Returns a new instance of EnvironmentVariable.
1038 1039 1040 |
# File 'lib/google/apis/firebaseapphosting_v1/classes.rb', line 1038 def initialize(**args) update!(**args) end |
Instance Attribute Details
#availability ⇒ Array<String>
Optional. Where this variable should be made available. If left unspecified,
will be available in both BUILD and BACKEND.
Corresponds to the JSON property availability
1002 1003 1004 |
# File 'lib/google/apis/firebaseapphosting_v1/classes.rb', line 1002 def availability @availability end |
#origin ⇒ String
Output only. The high-level origin category of the environment variable.
Corresponds to the JSON property origin
1007 1008 1009 |
# File 'lib/google/apis/firebaseapphosting_v1/classes.rb', line 1007 def origin @origin end |
#origin_file_name ⇒ String
Output only. Specific detail about the source. For APPHOSTING_YAML origins,
this will contain the exact filename, such as "apphosting.yaml" or "apphosting.
staging.yaml".
Corresponds to the JSON property originFileName
1014 1015 1016 |
# File 'lib/google/apis/firebaseapphosting_v1/classes.rb', line 1014 def origin_file_name @origin_file_name end |
#secret ⇒ String
A fully qualified secret version. The value of the secret will be accessed
once while building the application and once per cold start of the container
at runtime. The service account used by Cloud Build and by Cloud Run must each
have the secretmanager.versions.access permission on the secret.
Corresponds to the JSON property secret
1022 1023 1024 |
# File 'lib/google/apis/firebaseapphosting_v1/classes.rb', line 1022 def secret @secret end |
#value ⇒ String
A plaintext value. This value is encrypted at rest, but all project readers
can view the value when reading your backend configuration.
Corresponds to the JSON property value
1028 1029 1030 |
# File 'lib/google/apis/firebaseapphosting_v1/classes.rb', line 1028 def value @value end |
#variable ⇒ String
Required. The name of the environment variable. The environment variables
reserved by Cloud Run should not be set. Additionally,
variable names cannot start with "X_FIREBASE_".
Corresponds to the JSON property variable
1036 1037 1038 |
# File 'lib/google/apis/firebaseapphosting_v1/classes.rb', line 1036 def variable @variable end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1043 1044 1045 1046 1047 1048 1049 1050 |
# File 'lib/google/apis/firebaseapphosting_v1/classes.rb', line 1043 def update!(**args) @availability = args[:availability] if args.key?(:availability) @origin = args[:origin] if args.key?(:origin) @origin_file_name = args[:origin_file_name] if args.key?(:origin_file_name) @secret = args[:secret] if args.key?(:secret) @value = args[:value] if args.key?(:value) @variable = args[:variable] if args.key?(:variable) end |