Class: Google::Apis::FirebaseapphostingV1::RolloutPolicy
- Inherits:
-
Object
- Object
- Google::Apis::FirebaseapphostingV1::RolloutPolicy
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/firebaseapphosting_v1/classes.rb,
lib/google/apis/firebaseapphosting_v1/representations.rb,
lib/google/apis/firebaseapphosting_v1/representations.rb
Overview
The policy for how automatic builds and rollouts are triggered and rolled out.
Instance Attribute Summary collapse
-
#codebase_branch ⇒ String
If set, specifies a branch that triggers a new build to be started with this policy.
-
#disabled ⇒ Boolean
(also: #disabled?)
Optional.
-
#disabled_time ⇒ String
Output only.
-
#ignored_paths ⇒ Array<Google::Apis::FirebaseapphostingV1::Path>
Optional.
-
#required_paths ⇒ Array<Google::Apis::FirebaseapphostingV1::Path>
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ RolloutPolicy
constructor
A new instance of RolloutPolicy.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ RolloutPolicy
Returns a new instance of RolloutPolicy.
1710 1711 1712 |
# File 'lib/google/apis/firebaseapphosting_v1/classes.rb', line 1710 def initialize(**args) update!(**args) end |
Instance Attribute Details
#codebase_branch ⇒ String
If set, specifies a branch that triggers a new build to be started with this
policy. Otherwise, no automatic rollouts will happen.
Corresponds to the JSON property codebaseBranch
1677 1678 1679 |
# File 'lib/google/apis/firebaseapphosting_v1/classes.rb', line 1677 def codebase_branch @codebase_branch end |
#disabled ⇒ Boolean Also known as: disabled?
Optional. A flag that, if true, prevents automatic rollouts from being created
via this RolloutPolicy.
Corresponds to the JSON property disabled
1683 1684 1685 |
# File 'lib/google/apis/firebaseapphosting_v1/classes.rb', line 1683 def disabled @disabled end |
#disabled_time ⇒ String
Output only. If disabled is set, the time at which the automatic rollouts
were disabled.
Corresponds to the JSON property disabledTime
1690 1691 1692 |
# File 'lib/google/apis/firebaseapphosting_v1/classes.rb', line 1690 def disabled_time @disabled_time end |
#ignored_paths ⇒ Array<Google::Apis::FirebaseapphostingV1::Path>
Optional. A list of file paths patterns to exclude from triggering a rollout.
Patterns in this list take precedence over required_paths. Note: All paths
must be in the ignored_paths in order for the rollout to be skipped. Limited
to 100 paths. Example: ignored_paths: pattern: "foo/bar/excluded/*” type:
GLOB
Corresponds to the JSON property ignoredPaths
1699 1700 1701 |
# File 'lib/google/apis/firebaseapphosting_v1/classes.rb', line 1699 def ignored_paths @ignored_paths end |
#required_paths ⇒ Array<Google::Apis::FirebaseapphostingV1::Path>
Optional. A list of file paths patterns that trigger a build and rollout if at
least one of the changed files in the commit are present in this list. This
field is optional; the rollout policy will default to triggering on all paths
if not populated. Limited to 100 paths. Example: “required_paths: pattern: "
foo/bar/*” type: GLOB
Corresponds to the JSON property requiredPaths
1708 1709 1710 |
# File 'lib/google/apis/firebaseapphosting_v1/classes.rb', line 1708 def required_paths @required_paths end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1715 1716 1717 1718 1719 1720 1721 |
# File 'lib/google/apis/firebaseapphosting_v1/classes.rb', line 1715 def update!(**args) @codebase_branch = args[:codebase_branch] if args.key?(:codebase_branch) @disabled = args[:disabled] if args.key?(:disabled) @disabled_time = args[:disabled_time] if args.key?(:disabled_time) @ignored_paths = args[:ignored_paths] if args.key?(:ignored_paths) @required_paths = args[:required_paths] if args.key?(:required_paths) end |